<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//ja_JP

$LANG=array();


$LANG['backup'][0]="SQL形式でバックアップ"; 
$LANG['backup'][1]="XML形式でバックアップ"; 
$LANG['backup'][11]="サイズ"; 
$LANG['backup'][13]="表示/ダウンロード"; 
$LANG['backup'][16]="このバックアップファイルでデータベースを上書きします："; 
$LANG['backup'][17]="このファイルを削除する"; 
$LANG['backup'][18]="データベースのバックアップを取る"; 
$LANG['backup'][19]="実行"; 
$LANG['backup'][21]="このファイルはすでに存在します"; 
$LANG['backup'][22]="バイト文字列を見つけることができません"; 
$LANG['backup'][23]="Mysqlエラー："; 
$LANG['backup'][24]="自動転送、さもなくばクリック"; 

$LANG['bookmark'][1]="ブックマーク"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="まだブックマークを行っていません。"; 
$LANG['bookmark'][4]="新しいブックマーク"; 
$LANG['bookmark'][5]="公開ブックマーク"; 
$LANG['bookmark'][6]="デフォルトで許可"; 

$LANG['buttons'][0]="検索"; 
$LANG['buttons'][2]="更新/ログイン"; 
$LANG['buttons'][3]="関連付け"; 
$LANG['buttons'][4]="インストール"; 
$LANG['buttons'][5]="アンインストール"; 
$LANG['buttons'][6]="削除"; 
$LANG['buttons'][7]="更新"; 
$LANG['buttons'][8]="追加"; 
$LANG['buttons'][9]="接続"; 
$LANG['buttons'][10]="切断"; 
$LANG['buttons'][11]="次へ"; 
$LANG['buttons'][12]="先"; 
$LANG['buttons'][13]="前へ戻る"; 
$LANG['buttons'][14]="更新"; 
$LANG['buttons'][15]="予定表"; 
$LANG['buttons'][16]="クリア"; 
$LANG['buttons'][17]="選択の切り替え"; 
$LANG['buttons'][18]="全て選択"; 
$LANG['buttons'][19]="選択を全て解除"; 
$LANG['buttons'][20]="移動"; 
$LANG['buttons'][21]="リストア"; 
$LANG['buttons'][22]="消去"; 
$LANG['buttons'][23]="表示"; 
$LANG['buttons'][24]="上へ"; 
$LANG['buttons'][25]="下へ"; 
$LANG['buttons'][27]="PDFファイルでの現在のページ"; 
$LANG['buttons'][28]="SLKファイルでの現在のページ"; 
$LANG['buttons'][29]="PDFファイルの全ページ"; 
$LANG['buttons'][30]="SLKファイルの全ページ"; 
$LANG['buttons'][31]="出力"; 
$LANG['buttons'][32]="終了"; 
$LANG['buttons'][33]="開始"; 
$LANG['buttons'][34]="中止"; 
$LANG['buttons'][37]="インポート"; 
$LANG['buttons'][38]="ロックを解除"; 
$LANG['buttons'][39]="上書き"; 
$LANG['buttons'][40]="全てを表示"; 
$LANG['buttons'][41]="有効にする"; 
$LANG['buttons'][42]="無効にする"; 
$LANG['buttons'][43]="ブラウズする"; 
$LANG['buttons'][44]="CSVファイルでの現在のページ"; 
$LANG['buttons'][45]="CSVファイルの全ページ"; 
$LANG['buttons'][46]="その前に"; 
$LANG['buttons'][47]="その後"; 
$LANG['buttons'][48]="移動する"; 
$LANG['buttons'][49]="保存する"; 
$LANG['buttons'][50]="テスト"; 
$LANG['buttons'][51]="保存"; 
$LANG['buttons'][52]="読み込み"; 
$LANG['buttons'][53]="クリーニング"; 
$LANG['buttons'][55]="最初"; 
$LANG['buttons'][56]="最後"; 
$LANG['buttons'][57]="実行"; 
$LANG['buttons'][58]="更新"; 
$LANG['buttons'][59]="関連付けを解除"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="日"; 
$LANG['calendarD'][1]="月"; 
$LANG['calendarD'][2]="火"; 
$LANG['calendarD'][3]="水"; 
$LANG['calendarD'][4]="木"; 
$LANG['calendarD'][5]="金"; 
$LANG['calendarD'][6]="土"; 

$LANG['calendarDay'][0]="日曜日"; 
$LANG['calendarDay'][1]="月曜日"; 
$LANG['calendarDay'][2]="火曜日"; 
$LANG['calendarDay'][3]="水曜日"; 
$LANG['calendarDay'][4]="木曜日"; 
$LANG['calendarDay'][5]="金曜日"; 
$LANG['calendarDay'][6]="土曜日"; 

$LANG['calendarM'][0]="1月"; 
$LANG['calendarM'][1]="2月"; 
$LANG['calendarM'][2]="3月"; 
$LANG['calendarM'][3]="4月"; 
$LANG['calendarM'][4]="5月"; 
$LANG['calendarM'][5]="6月"; 
$LANG['calendarM'][6]="7月"; 
$LANG['calendarM'][7]="8月"; 
$LANG['calendarM'][8]="9月"; 
$LANG['calendarM'][9]="10月"; 
$LANG['calendarM'][10]="11月"; 
$LANG['calendarM'][11]="12月"; 

$LANG['cartridges'][0]="プリンタカートリッジ"; 
$LANG['cartridges'][7]="プリンタカートリッジが見付かりませんでした"; 
$LANG['cartridges'][9]="プリンタカートリッジ無し"; 
$LANG['cartridges'][10]="トナー"; 
$LANG['cartridges'][11]="インクジェット方式"; 
$LANG['cartridges'][12]="プリンタカートリッジ種別"; 
$LANG['cartridges'][13]="新品"; 
$LANG['cartridges'][14]="利用中"; 
$LANG['cartridges'][15]="使用済み"; 
$LANG['cartridges'][16]="本のカートリッジ"; 
$LANG['cartridges'][20]="新品"; 
$LANG['cartridges'][21]="利用中"; 
$LANG['cartridges'][22]="使用済み"; 
$LANG['cartridges'][24]="入荷日"; 
$LANG['cartridges'][27]="有効"; 
$LANG['cartridges'][29]="使用済みにする"; 
$LANG['cartridges'][32]="このカートリッジが利用出来るプリンタ型式"; 
$LANG['cartridges'][33]="利用中のプリンタカートリッジ"; 
$LANG['cartridges'][34]="在庫無し"; 
$LANG['cartridges'][35]="使用済みカートリッジ"; 
$LANG['cartridges'][37]="インクリボン"; 
$LANG['cartridges'][39]="プリンタカウンター"; 
$LANG['cartridges'][40]="平均在庫保有日数"; 
$LANG['cartridges'][41]="平均消耗日数"; 
$LANG['cartridges'][42]="平均印刷枚数"; 

$LANG['central'][2]="新着"; 
$LANG['central'][4]="イベント無し"; 
$LANG['central'][5]="ホーム"; 
$LANG['central'][6]="ログアウト"; 
$LANG['central'][7]="ヘルプ"; 
$LANG['central'][8]="件の履歴"; 
$LANG['central'][9]="処理中のチケット"; 
$LANG['central'][10]="新規チケット"; 
$LANG['central'][12]="個人"; 
$LANG['central'][13]="全体"; 
$LANG['central'][14]="グループビュー"; 
$LANG['central'][18]="クローズ中のチケット"; 
$LANG['central'][19]="有効なチケット"; 

$LANG['choice'][0]="いいえ"; 
$LANG['choice'][1]="はい"; 

$LANG['common'][0]="名前無し"; 
$LANG['common'][1]="アイテム"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="ゴミ箱の中を表示"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="メーカ"; 
$LANG['common'][6]="テンプレート名"; 
$LANG['common'][7]="テンプレートを選択"; 
$LANG['common'][8]="テンプレートを管理..."; 
$LANG['common'][9]="テンプレートを追加..."; 
$LANG['common'][10]="管理担当者"; 
$LANG['common'][11]="限定表示"; 
$LANG['common'][12]="セットアップ"; 
$LANG['common'][13]="テンプレート"; 
$LANG['common'][14]="テンプレート"; 
$LANG['common'][15]="場所"; 
$LANG['common'][16]="名前"; 
$LANG['common'][17]="種別"; 
$LANG['common'][18]="代替ユーザー名"; 
$LANG['common'][19]="シリアル場号"; 
$LANG['common'][20]="構成管理番号"; 
$LANG['common'][21]="代替ユーザー番号"; 
$LANG['common'][22]="型式"; 
$LANG['common'][23]="操作は成功しました"; 
$LANG['common'][24]="アイテムが選択されてないか、操作が規定されていません"; 
$LANG['common'][25]="備考"; 
$LANG['common'][26]="最終アップデート"; 
$LANG['common'][27]="日付"; 
$LANG['common'][28]="削除しました"; 
$LANG['common'][29]="プラグイン"; 
$LANG['common'][30]="新しいアイテム"; 
$LANG['common'][31]="空のテンプレート"; 
$LANG['common'][32]="プロパティ"; 
$LANG['common'][33]="合計"; 
$LANG['common'][34]="ユーザ"; 
$LANG['common'][35]="グループ"; 
$LANG['common'][36]="カテゴリー"; 
$LANG['common'][37]="作成者"; 
$LANG['common'][38]="単品管理を使用"; 
$LANG['common'][39]="接続アイテムをコピー"; 
$LANG['common'][40]="このアイテムに単品管理を適用しますか？"; 
$LANG['common'][41]="E-mailアラート"; 
$LANG['common'][42]="携帯電話"; 
$LANG['common'][43]="名前"; 
$LANG['common'][44]="初期値"; 
$LANG['common'][45]="最大MB"; 
$LANG['common'][46]="VCARD"; 
$LANG['common'][47]="対応状況"; 
$LANG['common'][48]="名字"; 
$LANG['common'][49]="なし"; 
$LANG['common'][50]="本当に削除してもよろしいですか？"; 
$LANG['common'][51]="完全な名前"; 
$LANG['common'][52]="サーバ"; 
$LANG['common'][53]="リスト"; 
$LANG['common'][54]="アイテムが見つかりません"; 
$LANG['common'][55]="本当にこの要素を削除してよろしいですか？"; 
$LANG['common'][56]="標準インターフェイス"; 
$LANG['common'][57]="タイトル"; 
$LANG['common'][58]="最大値"; 
$LANG['common'][59]="グローバル"; 
$LANG['common'][60]="アクティブ"; 
$LANG['common'][61]="不明なエラー"; 
$LANG['common'][62]="その他"; 
$LANG['common'][63]="エラー"; 
$LANG['common'][64]="マネージャー"; 
$LANG['common'][65]="インターフェース"; 
$LANG['common'][66]="全て"; 
$LANG['common'][67]="他のもの"; 
$LANG['common'][68]="ランドスケープ（横）"; 
$LANG['common'][69]="ポートレート（縦）"; 
$LANG['common'][70]="アイテムの追加に成功しました"; 
$LANG['common'][71]="アイテムの更新に成功しました"; 
$LANG['common'][72]="アイテムの削除に成功しました"; 
$LANG['common'][73]="アイテムの完全消去に成功しました"; 
$LANG['common'][74]="アイテムの復活に成功しました"; 
$LANG['common'][75]="このエンティティでこのアイテムを再帰化する権利はありません"; 
$LANG['common'][76]="公開"; 
$LANG['common'][77]="プライベート"; 
$LANG['common'][78]="公開に設定する"; 
$LANG['common'][79]="プライベートに設定"; 
$LANG['common'][80]="ロードしています"; 
$LANG['common'][81]="削除アイテムを表示しない"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="この操作をおこなう権限がありません。"; 
$LANG['common'][84]="フラグの変更は禁止されています。リンク先にアイテムが見つかりました。"; 
$LANG['common'][85]="子エンティティの可視属性を変更する"; 
$LANG['common'][86]="子エンティティの表示属性を変更することはできません。"; 
$LANG['common'][87]="新しいカード"; 
$LANG['common'][88]="個人の"; 
$LANG['common'][89]="未インストール"; 
$LANG['common'][90]="オブジェクト"; 
$LANG['common'][91]="この属性を変更することはできません。上位から引き継ぎます。"; 
$LANG['common'][92]="代替ユーザー名"; 
$LANG['common'][93]="新しい子オブジェクト見出し"; 

$LANG['computers'][0]="ボリューム"; 
$LANG['computers'][1]="空き領域％"; 
$LANG['computers'][2]="空き領域"; 
$LANG['computers'][3]="全領域"; 
$LANG['computers'][4]="ファイルシステム"; 
$LANG['computers'][5]="マウントポイント"; 
$LANG['computers'][6]="パーティション"; 
$LANG['computers'][7]="ボリュームを追加する"; 
$LANG['computers'][8]="ボリューム"; 
$LANG['computers'][9]="OS"; 
$LANG['computers'][10]="OSのシリアル番号"; 
$LANG['computers'][11]="OSのプロダクトID"; 
$LANG['computers'][14]="挿入済み"; 
$LANG['computers'][23]="メモリ種別"; 
$LANG['computers'][24]="メモリ(MB)"; 
$LANG['computers'][25]="ハードディスクサイズ"; 
$LANG['computers'][36]="ハードディスク種別"; 
$LANG['computers'][37]="モニタ無し"; 
$LANG['computers'][38]="プリンタ無し"; 
$LANG['computers'][39]="プリンタ"; 
$LANG['computers'][40]="モニタ"; 
$LANG['computers'][46]="周辺機器"; 
$LANG['computers'][47]="周辺機器無し"; 
$LANG['computers'][48]="設置場所を変更しました"; 
$LANG['computers'][49]="代替ユーザー名を更新しました。関連アイテムがこの代替ユーザー名を用いて更新されます。"; 
$LANG['computers'][50]="グループを変更しました"; 
$LANG['computers'][51]="更新方法"; 
$LANG['computers'][52]="OSバージョン"; 
$LANG['computers'][53]="サービスパック"; 
$LANG['computers'][54]="電話無し"; 
$LANG['computers'][55]="電話"; 
$LANG['computers'][56]="ステータスは更新されました。関連アイテムも同時に更新されています。"; 

$LANG['connect'][0]="直接接続されたデバイス"; 
$LANG['connect'][1]="接続無し"; 
$LANG['connect'][15]="以下のアイテムの自動更新"; 
$LANG['connect'][16]="警告！以下の2つのハードウェアのアイテムは整合しません。"; 

$LANG['consumables'][0]="消耗品"; 
$LANG['consumables'][1]="在庫"; 
$LANG['consumables'][2]="参考"; 
$LANG['consumables'][7]="消耗品が見付かりませんでした"; 
$LANG['consumables'][9]="消耗品無し"; 
$LANG['consumables'][12]="消耗品型番"; 
$LANG['consumables'][13]="新品"; 
$LANG['consumables'][15]="利用中"; 
$LANG['consumables'][16]="個の消耗品"; 
$LANG['consumables'][20]="新品"; 
$LANG['consumables'][22]="使用済み"; 
$LANG['consumables'][23]="状態"; 
$LANG['consumables'][26]="使用日"; 
$LANG['consumables'][32]="ユーザに消耗品を割り当て"; 
$LANG['consumables'][35]="使用済み消耗品"; 
$LANG['consumables'][36]="在庫の場所"; 
$LANG['consumables'][37]="在庫に戻す"; 
$LANG['consumables'][38]="警告の閾値"; 

$LANG['contract'][0]="で契約終了"; 
$LANG['contract'][1]="から通知により契約開始"; 

$LANG['crontask'][0]="自動実行"; 
$LANG['crontask'][1]="OCSNGと同期"; 
$LANG['crontask'][2]="カートリッジ警告を送信"; 
$LANG['crontask'][3]="消耗品警告を送信"; 
$LANG['crontask'][4]="失効ライセンス警告を送信"; 
$LANG['crontask'][5]="契約警告を送信"; 
$LANG['crontask'][6]="財務情報警告を送信"; 
$LANG['crontask'][7]="古いログの消去"; 
$LANG['crontask'][8]="データベースの最適化"; 
$LANG['crontask'][9]="メールを開く（メール受信者）"; 
$LANG['crontask'][10]="MySQLの複製の確認"; 
$LANG['crontask'][11]="新しい更新の確認"; 
$LANG['crontask'][12]="期限切れセッションの消去"; 
$LANG['crontask'][13]="生成された画像の消去"; 
$LANG['crontask'][14]="チケット自動終了"; 
$LANG['crontask'][15]="未解決チケット"; 
$LANG['crontask'][31]="無効化された"; 
$LANG['crontask'][32]="予定済み"; 
$LANG['crontask'][33]="動作"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="動作モード"; 
$LANG['crontask'][37]="動作頻度"; 
$LANG['crontask'][38]="動作サイクル"; 
$LANG['crontask'][39]="未読のE-mail数"; 
$LANG['crontask'][40]="前回動作"; 
$LANG['crontask'][41]="次の動作"; 
$LANG['crontask'][42]="できる限り早く"; 
$LANG['crontask'][43]="待機中のタスクはありません"; 
$LANG['crontask'][44]="タスク終了（一部対応）"; 
$LANG['crontask'][45]="タスク終了（完了）"; 
$LANG['crontask'][46]="タスク終了（未対応）"; 
$LANG['crontask'][47]="前回動作リスト"; 
$LANG['crontask'][48]="開始"; 
$LANG['crontask'][50]="動作カウント"; 
$LANG['crontask'][51]="最小時間"; 
$LANG['crontask'][52]="最大時間"; 
$LANG['crontask'][53]="平均時間"; 
$LANG['crontask'][55]="最小カウント"; 
$LANG['crontask'][56]="最大カウント"; 
$LANG['crontask'][57]="平均カウント"; 
$LANG['crontask'][58]="合計カウント"; 
$LANG['crontask'][59]="平均スピード"; 
$LANG['crontask'][60]="システムロック"; 
$LANG['crontask'][61]="無効なプラグイン"; 
$LANG['crontask'][62]="要素"; 

$LANG['devices'][0]="新しいPC内部パーツを追加"; 
$LANG['devices'][1]="ハードディスク"; 
$LANG['devices'][2]="ビデオカード"; 
$LANG['devices'][3]="ネットワークカード"; 
$LANG['devices'][4]="プロセッサ"; 
$LANG['devices'][5]="マザーボード"; 
$LANG['devices'][6]="メモリ"; 
$LANG['devices'][7]="サウンドカード"; 
$LANG['devices'][19]="ドライブ"; 
$LANG['devices'][20]="コントローラ"; 
$LANG['devices'][21]="その他のPC内部パーツ"; 
$LANG['devices'][22]="ケース"; 
$LANG['devices'][23]="電源ユニット"; 
$LANG['devices'][24]="基本"; 
$LANG['devices'][25]="PC内部パーツを追加"; 
$LANG['devices'][26]="PC内部パーツを削除"; 

$LANG['device_case'][0]="サイズ"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="書き込み可能"; 
$LANG['device_drive'][1]="速度"; 

$LANG['device_hdd'][0]="回転速度（RPM）"; 
$LANG['device_hdd'][1]="キャッシュのサイズ"; 
$LANG['device_hdd'][4]="容量"; 

$LANG['device_iface'][0]="Flow"; 
$LANG['device_iface'][2]="MACアドレス"; 

$LANG['device_moboard'][0]="チップセット"; 

$LANG['device_power'][0]="電源"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="周波数"; 
$LANG['device_ram'][2]="サイズ"; 

$LANG['document'][1]="チェックサム(SHA1)"; 
$LANG['document'][2]="ファイル"; 
$LANG['document'][3]="表題"; 
$LANG['document'][4]="MIME種別"; 
$LANG['document'][7]="ドキュメント種別"; 
$LANG['document'][9]="拡張子"; 
$LANG['document'][10]="アイコン"; 
$LANG['document'][11]="認証されたダウンロード"; 
$LANG['document'][15]="ダウンロード"; 
$LANG['document'][16]="ドキュメントを追加"; 
$LANG['document'][18]="ドキュメント"; 
$LANG['document'][19]="関連するアイテム"; 
$LANG['document'][21]="関連するドキュメント"; 
$LANG['document'][22]="現在のファイル"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="ファイルを削除しました"; 
$LANG['document'][25]="ファイルを削除出来ませんでした"; 
$LANG['document'][26]="アップロードに成功しました"; 
$LANG['document'][27]="ファイルが大き過ぎるため、一時ファイルの移動に失敗しました"; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="ディレクトリ作成に失敗しました"; 
$LANG['document'][30]="権限を確認して下さい"; 
$LANG['document'][31]="ドキュメントためのディレクトリが存在しません"; 
$LANG['document'][32]="未知のファイル種別"; 
$LANG['document'][33]="ウェブリンク"; 
$LANG['document'][34]="ディレクトリーを作成"; 
$LANG['document'][35]="アップロードディレクトリが存在しません"; 
$LANG['document'][36]="FTPでインストールしたファイルを選択"; 
$LANG['document'][37]="ファイルが無い"; 
$LANG['document'][38]="ファイルが見付かりませんでした"; 
$LANG['document'][39]="ドキュメントを移動しました"; 
$LANG['document'][40]="ファイルの移動が失敗しました"; 
$LANG['document'][41]="ドキュメントをコピーしました"; 
$LANG['document'][42]="編集者"; 
$LANG['document'][43]="不明ファイル"; 
$LANG['document'][44]="使用出来ないファイル名"; 
$LANG['document'][45]="ファイルアクセスが禁止されています"; 
$LANG['document'][46]="ファイル送信失敗（サイズ過大）"; 
$LANG['document'][48]="このファイルにはドキュメントがすでに存在します。"; 
$LANG['document'][49]="ファイルは変更されています。（チェックサム不一致)"; 
$LANG['document'][50]="添付アイテム"; 

$LANG['entity'][0]="エンティティ"; 
$LANG['entity'][2]="ルートエンティティ"; 
$LANG['entity'][3]="エンティティを共有する"; 
$LANG['entity'][5]="コンピュータの自動割り当て"; 
$LANG['entity'][6]="自動ユーザ割り当て"; 
$LANG['entity'][7]="ツリー構造"; 
$LANG['entity'][8]="エンティティによって"; 
$LANG['entity'][9]="子エンティティ"; 
$LANG['entity'][10]="要望のエンティティを選択"; 
$LANG['entity'][11]="エンティティとサブエンティティを確認する。"; 
$LANG['entity'][12]="LDAPが属性付けするエンティティ"; 
$LANG['entity'][13]="TAGで識別するエンティティ"; 
$LANG['entity'][14]="詳細情報"; 
$LANG['entity'][15]="エンティティのLDAPディレクトリ"; 
$LANG['entity'][16]="検索フィルター（必要な場合）"; 
$LANG['entity'][17]="自動終了設定"; 
$LANG['entity'][18]="以降のチケットの自動終了"; 

$LANG['event'][0]="ソース"; 
$LANG['event'][2]="サービス"; 
$LANG['event'][3]="レベル"; 
$LANG['event'][4]="メッセージ"; 
$LANG['event'][18]="フィールド"; 
$LANG['event'][19]="アップデート"; 
$LANG['event'][20]="履歴がありません"; 

$LANG['financial'][1]="契約情報管理"; 
$LANG['financial'][2]="有効"; 
$LANG['financial'][3]="財務情報"; 
$LANG['financial'][4]="番号"; 
$LANG['financial'][5]="価格"; 
$LANG['financial'][6]="契約種別"; 
$LANG['financial'][8]="契約期間"; 
$LANG['financial'][9]="何年"; 
$LANG['financial'][10]="予告"; 
$LANG['financial'][11]="請求書の送付サイクル"; 
$LANG['financial'][13]="口座番号"; 
$LANG['financial'][14]="購入日"; 
$LANG['financial'][15]="保証期間"; 
$LANG['financial'][16]="保証情報"; 
$LANG['financial'][18]="注文番号"; 
$LANG['financial'][19]="配達情報"; 
$LANG['financial'][20]="財務管理番号"; 
$LANG['financial'][21]="価格"; 
$LANG['financial'][22]="償却種別"; 
$LANG['financial'][23]="償却期間"; 
$LANG['financial'][24]="連絡先を追加..."; 
$LANG['financial'][25]="メーカを追加..."; 
$LANG['financial'][26]="メーカ"; 
$LANG['financial'][30]="FAX番号"; 
$LANG['financial'][33]="連絡先を追加"; 
$LANG['financial'][36]="契約を追加"; 
$LANG['financial'][42]="業種"; 
$LANG['financial'][43]="技術者"; 
$LANG['financial'][44]="住所"; 
$LANG['financial'][45]="ウェブサイト"; 
$LANG['financial'][46]="提携連絡先"; 
$LANG['financial'][47]="定額"; 
$LANG['financial'][48]="逓減"; 
$LANG['financial'][50]="ローン"; 
$LANG['financial'][51]="レンタル"; 
$LANG['financial'][52]="リース"; 
$LANG['financial'][53]="保険"; 
$LANG['financial'][54]="ハードウェアサポート"; 
$LANG['financial'][55]="ソフトウエアサポート"; 
$LANG['financial'][56]="提供サービス"; 
$LANG['financial'][57]="ヶ月"; 
$LANG['financial'][59]="サポート時間"; 
$LANG['financial'][60]="平日"; 
$LANG['financial'][61]="土曜日"; 
$LANG['financial'][62]="日曜日・祝日"; 
$LANG['financial'][65]="関連メーカ"; 
$LANG['financial'][66]="契約関連情報"; 
$LANG['financial'][68]="財務情報"; 
$LANG['financial'][69]="契約有効期間"; 
$LANG['financial'][76]="開始日付"; 
$LANG['financial'][77]="償却係数"; 
$LANG['financial'][78]="保証期限切れ価値"; 
$LANG['financial'][79]="供給形態"; 
$LANG['financial'][80]="保証終了日"; 
$LANG['financial'][81]="口座価格（net value of this account）"; 
$LANG['financial'][82]="請求書番号"; 
$LANG['financial'][83]="最大アイテム数"; 
$LANG['financial'][84]="このタイプの財務情報は、モデル種別に依存し、ただ一つであるべきです"; 
$LANG['financial'][85]="アイテムが見付かりませんでした"; 
$LANG['financial'][86]="契約の終了"; 
$LANG['financial'][87]="予算"; 
$LANG['financial'][88]="終了日"; 
$LANG['financial'][89]="TCO （価格 + 運用価格）"; 
$LANG['financial'][90]="月次TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="契約の終了から30日以内"; 
$LANG['financial'][94]="契約の終了まで7日以内"; 
$LANG['financial'][95]="契約の終了まで30日以内"; 
$LANG['financial'][96]="契約の終了を通知するまで7日以内"; 
$LANG['financial'][97]="契約の終了を通知するまで30日以内"; 
$LANG['financial'][98]="終了日"; 
$LANG['financial'][99]="終了日 + 終了の通知"; 
$LANG['financial'][100]="郵便番号"; 
$LANG['financial'][101]="市"; 
$LANG['financial'][102]="県"; 
$LANG['financial'][103]="国"; 
$LANG['financial'][104]="関連アイテム"; 
$LANG['financial'][105]="暗黙の了解"; 
$LANG['financial'][106]="Express"; 
$LANG['financial'][107]="更新"; 
$LANG['financial'][108]="予算消化計"; 
$LANG['financial'][109]="予算残高計"; 
$LANG['financial'][110]="予算"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="時間"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="優先順位のマトリクス解析"; 
$LANG['help'][2]="主要な"; 
$LANG['help'][3]="緊急"; 
$LANG['help'][4]="高"; 
$LANG['help'][5]="中"; 
$LANG['help'][6]="低"; 
$LANG['help'][7]="低以下"; 
$LANG['help'][8]="解決方法"; 
$LANG['help'][11]="E-mail"; 
$LANG['help'][14]="送信"; 
$LANG['help'][16]="結果の通知を受け取るためには、E-mailアドレスを入力する必要があります。"; 
$LANG['help'][18]="送信完了。リクエストは保存されました。"; 
$LANG['help'][19]="ご利用ありがとうございました。"; 
$LANG['help'][22]="コンピュータIDで検索"; 
$LANG['help'][23]="先頭文字を入力して下さい（ユーザー名、アイテム名、シリアル番号もしくはアセット番号）"; 
$LANG['help'][24]="ハードウェア 種別"; 
$LANG['help'][25]="コンピュータ"; 
$LANG['help'][26]="ネットワーク機器"; 
$LANG['help'][27]="プリンタ"; 
$LANG['help'][28]="モニタ"; 
$LANG['help'][29]="周辺機器"; 
$LANG['help'][30]="一般"; 
$LANG['help'][31]="ソフトウエア"; 
$LANG['help'][35]="電話"; 
$LANG['help'][40]="チケットにタイトルがありません。再試行して下さい。"; 
$LANG['help'][41]="チケットにカテゴリがありません。再試行して下さい。"; 
$LANG['help'][42]="大変高い"; 
$LANG['help'][43]="高"; 
$LANG['help'][44]="中"; 
$LANG['help'][45]="低"; 
$LANG['help'][46]="大変低い"; 
$LANG['help'][47]="大変高い"; 
$LANG['help'][48]="高"; 
$LANG['help'][49]="中"; 
$LANG['help'][50]="低"; 
$LANG['help'][51]="大変低い"; 

$LANG['install'][0]="GLPIのインストールまたはアップデートを実行"; 
$LANG['install'][1]="GLPIのクリーンインストールを実行する場合は「インストール」を選択して下さい。"; 
$LANG['install'][2]="GLPIのアップデートを実行する場合「アップデート」を選択して下さい。"; 
$LANG['install'][3]="インストール"; 
$LANG['install'][4]="アップデート"; 
$LANG['install'][5]="環境を確認しています"; 
$LANG['install'][6]="確認完了"; 
$LANG['install'][7]="詳細"; 
$LANG['install'][8]="PHPを確認中"; 
$LANG['install'][9]="PHP5以上をインストールする必要があります。"; 
$LANG['install'][10]="GLPIは'zend.ze1_compatibility_mode = On'のオプションでは動作しません。"; 
$LANG['install'][11]="PHPのバージョン － 5.x以上 （問題なし！）"; 
$LANG['install'][12]="セッションを確認中"; 
$LANG['install'][13]="PHPにセッションサポートが入っていません"; 
$LANG['install'][14]="PHPにセッションサポートが入っています"; 
$LANG['install'][15]="php.iniのセッションサポートが有効である事を確認して下さい"; 
$LANG['install'][16]="ファイルの書き込み権限を確認中"; 
$LANG['install'][17]="ファイルが作成出来ませんでした"; 
$LANG['install'][18]="非公式の変換も有効とする"; 
$LANG['install'][19]="ファイルを作成しましたが、削除出来ません"; 
$LANG['install'][20]="ファイル及びディレクトリは作成及び削除されました－完全に！"; 
$LANG['install'][21]="文章ファイルの書き込み権限を確認中"; 
$LANG['install'][22]="ファイルは作成されました－問題なし！"; 
$LANG['install'][23]="設定ファイルの書き込み権限を確認中"; 
$LANG['install'][24]="データベース初期化"; 
$LANG['install'][25]="実行しますか？"; 
$LANG['install'][26]="実行"; 
$LANG['install'][27]="再実行"; 
$LANG['install'][28]="データベース接続の設定"; 
$LANG['install'][29]="データベース接続のパラメータ"; 
$LANG['install'][30]="MySQLサーバー名"; 
$LANG['install'][31]="MySQLユーザー"; 
$LANG['install'][32]="MySQLパスワード"; 
$LANG['install'][34]="データベースの接続を確認"; 
$LANG['install'][35]="データベースへ接続出来ませんでした"; 
$LANG['install'][36]="サーバーから受信成功"; 
$LANG['install'][37]="サーバー名もしくはユーザー名が空です。"; 
$LANG['install'][38]="データベースを選択して下さい："; 
$LANG['install'][39]="新しいデータベースを作成するか、既存のデータベースを使ってください："; 
$LANG['install'][40]="アップデートするデータベースを選択して下さい："; 
$LANG['install'][41]="データベースを使用出来ません："; 
$LANG['install'][43]="データベース起動に成功しました"; 
$LANG['install'][47]="データベースセットアップファイルに書き込み出来ません"; 
$LANG['install'][48]="データベースの作成に失敗しました"; 
$LANG['install'][49]="データベースが選択されていません"; 
$LANG['install'][50]="セッションファイルの書き込み権限を確認中"; 
$LANG['install'][52]="自動実行ファイルの書き込み権限を確認"; 
$LANG['install'][53]="ログの書き込みファイルのテスト"; 
$LANG['install'][55]="インストール完了しました"; 
$LANG['install'][57]="デフォルトログイン名/パスワードは："; 
$LANG['install'][58]="管理者：glpi/glpi"; 
$LANG['install'][59]="技術者：tech/tech"; 
$LANG['install'][60]="標準/標準アカウント用"; 
$LANG['install'][61]="投稿のみ/投稿専用アカウント用"; 
$LANG['install'][62]="ユーザは初期設定と同様にこれらのアカウントを削除もしくは修正することができます。"; 
$LANG['install'][64]="GLPIを使用"; 
$LANG['install'][65]="magic_quotes_sybaseオプションを確認"; 
$LANG['install'][66]="magic_quotes_sybaseオプションが有効になっているためGLPIを使用出来ません。無効にして下さい。"; 
$LANG['install'][67]="magic_quotes_sybaseオプションが無効になっています"; 
$LANG['install'][68]="テストセッションの自動スタート"; 
$LANG['install'][69]="session.auto_startが有効になりました。詳細はGLPIルートの.htaccessファイルを参照して下さい。"; 
$LANG['install'][70]="データベース接続ファイルが作成出来ません、書き込み権限を確認して下さい。"; 
$LANG['install'][71]="MySQLを確認"; 
$LANG['install'][72]="PHPにMySQLが入っていません"; 
$LANG['install'][73]="mysql_query（）に成功しました"; 
$LANG['install'][74]="Session_use_trans_idを確認"; 
$LANG['install'][75]="php.iniのSession_use_trans_idオプションが無効である事を確認して下さい"; 
$LANG['install'][76]="Session_use_trans_idに成功しました"; 
$LANG['install'][77]="次へ"; 
$LANG['install'][81]="インストールを開始しました"; 
$LANG['install'][82]="データベースを作成出来ました"; 
$LANG['install'][85]="utf8_encodeとutf8_decodeに成功しました"; 
$LANG['install'][86]="割り当てメモリを確認"; 
$LANG['install'][87]="割り当てメモリ："; 
$LANG['install'][88]="GLPIの起動には通常64MB以上必要です"; 
$LANG['install'][89]="メモリ確認に成功しました"; 
$LANG['install'][90]="php.iniのmemory_limit parameterを確認して下さい"; 
$LANG['install'][91]="割り当てメモリ － 64MB以上"; 
$LANG['install'][92]="ライセンス"; 
$LANG['install'][93]="ライセンス契約を読んで同意します"; 
$LANG['install'][94]="ライセンス契約を読んで同意しません"; 
$LANG['install'][95]="メモリ制限無し"; 
$LANG['install'][96]="メモリ制限無し"; 
$LANG['install'][97]="ディレクトリへのアクセス権限を確認してください。"; 
$LANG['install'][99]="キャッシュファイルのための権限を確認する"; 
$LANG['install'][100]="Directoryは作成されませんでした。"; 
$LANG['install'][101]="Directoryは作成されましたが、移動できませんでした。"; 
$LANG['install'][102]="json関数をテストする。"; 
$LANG['install'][103]="GLPIはjson_encode及びjson_decode関数がなければ正常に動作しません。"; 
$LANG['install'][104]="mbstring拡張テスト"; 
$LANG['install'][105]="PHPにmbstring拡張がインストールされていません。"; 
$LANG['install'][106]="画像ファイルの書き込み権限を確認中"; 

$LANG['job'][2]="によって"; 
$LANG['job'][4]="依頼者"; 
$LANG['job'][5]="担当者"; 
$LANG['job'][6]="技術者"; 
$LANG['job'][7]="タスク"; 
$LANG['job'][8]="チケットを継続"; 
$LANG['job'][9]="フォローアップ"; 
$LANG['job'][11]="問題と対応を記述して下さい。"; 
$LANG['job'][12]="このチケットはフォローされていません"; 
$LANG['job'][13]="新しいチケット"; 
$LANG['job'][15]="解決済み"; 
$LANG['job'][19]="E-mailでフォロー"; 
$LANG['job'][20]="経過時間"; 
$LANG['job'][21]="時間"; 
$LANG['job'][22]="分"; 
$LANG['job'][29]="新しい対応内容を追加"; 
$LANG['job'][30]="新しいタスクを追加する"; 
$LANG['job'][31]="経過時間"; 
$LANG['job'][32]="無し"; 
$LANG['job'][33]="詳細が空です"; 
$LANG['job'][34]="タスクを計画する"; 
$LANG['job'][35]="予定表"; 
$LANG['job'][37]="一覧"; 
$LANG['job'][38]="チケット"; 
$LANG['job'][39]="アップデートされた対応内容"; 
$LANG['job'][40]="時間コスト"; 
$LANG['job'][41]="固定コスト"; 
$LANG['job'][42]="材料費"; 
$LANG['job'][43]="総経費"; 
$LANG['job'][44]="依頼元"; 
$LANG['job'][45]="フォローアップ元"; 
$LANG['job'][46]="チケットはエンティティで追加されます"; 
$LANG['job'][47]="コスト"; 
$LANG['job'][48]="ソリューションのタイプ"; 
$LANG['job'][49]="新しいタスク"; 
$LANG['job'][50]="このチケットにタスクなし"; 
$LANG['job'][51]="ソリューションの承認"; 
$LANG['job'][52]="タスクを更新"; 
$LANG['job'][53]="タスクの削除"; 
$LANG['job'][54]="チケットは応答なく自動的にクローズされます"; 

$LANG['joblist'][0]="ステータス"; 
$LANG['joblist'][1]="私の担当"; 
$LANG['joblist'][2]="重要度"; 
$LANG['joblist'][3]="個人 + グループ"; 
$LANG['joblist'][4]="担当者割り当て"; 
$LANG['joblist'][6]="詳細"; 
$LANG['joblist'][7]="新しいチケットを追加..."; 
$LANG['joblist'][8]="チケットが見付かりませんでした"; 
$LANG['joblist'][9]="新規チケット"; 
$LANG['joblist'][10]="完了（解決）"; 
$LANG['joblist'][11]="発生日"; 
$LANG['joblist'][12]="解決日"; 
$LANG['joblist'][13]="処理すべきチケット"; 
$LANG['joblist'][14]="解決済み"; 
$LANG['joblist'][16]="処理中のチケットはありません"; 
$LANG['joblist'][17]="完了（未解決）"; 
$LANG['joblist'][18]="対応中（担当者割り当て済み）"; 
$LANG['joblist'][19]="対応中（計画済み）"; 
$LANG['joblist'][21]="対応進行中"; 
$LANG['joblist'][26]="未解決"; 
$LANG['joblist'][27]="E-mailで対応内容を送信"; 
$LANG['joblist'][28]="アイテムにリンクしたチケット"; 
$LANG['joblist'][29]="緊急"; 
$LANG['joblist'][30]="影響"; 
$LANG['joblist'][32]="解決済み"; 
$LANG['joblist'][33]="クローズ済み"; 
$LANG['joblist'][34]="未解決"; 
$LANG['joblist'][35]="未完了"; 
$LANG['joblist'][36]="データベースのステータス値"; 

$LANG['jobresolution'][1]="解決"; 
$LANG['jobresolution'][3]="承認されたソリューション"; 
$LANG['jobresolution'][4]="拒否されたソリューション"; 
$LANG['jobresolution'][5]="ソリューションを却下する場合、理由を明確にして下さい。"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="このアイテムをFAQに追加"; 
$LANG['knowbase'][6]="アイテムのカテゴリを選択："; 
$LANG['knowbase'][7]="FAQからこのアイテムを削除"; 
$LANG['knowbase'][8]="アイテムを編集"; 
$LANG['knowbase'][9]="アイテムを削除"; 
$LANG['knowbase'][10]="このアイテムはFAQのアイテムです"; 
$LANG['knowbase'][11]="このアイテムはFAQのアイテムではありません"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="カテゴリ名"; 
$LANG['knowbase'][14]="題名"; 
$LANG['knowbase'][15]="内容"; 
$LANG['knowbase'][24]="FAQへのアクセス"; 
$LANG['knowbase'][26]="表示"; 
$LANG['knowbase'][27]="有効"; 
$LANG['knowbase'][29]="最近のエントリー"; 
$LANG['knowbase'][30]="最も多い質問"; 

$LANG['ldap'][0]="LDAP ディレクトリからインポートしたユーザー"; 
$LANG['ldap'][1]="インポート済みユーザーの同期"; 
$LANG['ldap'][2]="新しいユーザをインポート"; 
$LANG['ldap'][3]="インポートされるユーザが見つかりません"; 
$LANG['ldap'][4]="LDAP Directory選択"; 
$LANG['ldap'][5]="からユーザをインポートするにはLDAP Directoryを選択してください。"; 
$LANG['ldap'][6]="LDAPDirectoryに接続できません。"; 
$LANG['ldap'][7]="GLPIに定義されたLDAP Directoryが見つかりません"; 
$LANG['ldap'][8]="警告：リクエストはディレクトリの制限を越えています。表示された結果は一部分です。"; 
$LANG['ldap'][9]="LDAP Directoryへのテスト接続"; 
$LANG['ldap'][12]="同期"; 
$LANG['ldap'][13]="LDAPディレクトリにおいて"; 
$LANG['ldap'][14]="GLPIにおいて"; 
$LANG['ldap'][15]="同期を取る"; 
$LANG['ldap'][16]="事前設定"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="LDAPディレクトリ複製リスト"; 
$LANG['ldap'][19]="複製する"; 
$LANG['ldap'][20]="LDAPディレクトリの複製を追加"; 
$LANG['ldap'][21]="メインサーバ"; 
$LANG['ldap'][22]="複製"; 
$LANG['ldap'][23]="LDAP ディレクトリからインポートしたグループ"; 
$LANG['ldap'][24]="新しいグループのインポート"; 
$LANG['ldap'][25]="インポートされたグループはありません"; 
$LANG['ldap'][30]="LDAP エイリアスの取り扱い"; 
$LANG['ldap'][31]="LDAP参照を更新しない（デフォルト）"; 
$LANG['ldap'][32]="常にLDAP参照を更新する"; 
$LANG['ldap'][33]="検索中にLDAP参照を更新（割り当て時以外）"; 
$LANG['ldap'][34]="割り当て時にLDAP参照を更新（検索中以外）"; 
$LANG['ldap'][35]="ユーザーをインポート"; 
$LANG['ldap'][36]="エンティティに関連するディレクトリなし：検索不可"; 
$LANG['ldap'][38]="ユーザー検索条件"; 
$LANG['ldap'][39]="詳細"; 
$LANG['ldap'][40]="単純"; 
$LANG['ldap'][41]="変更するには"; 
$LANG['ldap'][42]="ディレクトリが未選択"; 
$LANG['ldap'][43]="同期すべきユーザーなし"; 
$LANG['ldap'][44]="デフォルトサーバー"; 
$LANG['ldap'][45]="ユーザーがLDAPディレクトリから削除されたときの動作"; 
$LANG['ldap'][46]="権限とグループを削除（動的）"; 
$LANG['ldap'][47]="ゴミ箱へ"; 
$LANG['ldap'][48]="LDAPディレクトリから削除されたユーザー"; 
$LANG['ldap'][49]="以降に追加されたユーザー一覧"; 
$LANG['ldap'][50]="以降に更新されたユーザー一覧"; 
$LANG['ldap'][52]="より少ない"; 
$LANG['ldap'][53]="より多い"; 
$LANG['ldap'][54]="日付フィルタリング有効"; 
$LANG['ldap'][55]="日付フィルタリング無効"; 
$LANG['ldap'][56]="週"; 

$LANG['links'][1]="リンク先かファイル名"; 
$LANG['links'][4]="関連ハードウェア種別"; 
$LANG['links'][6]="有効なタグ"; 
$LANG['links'][7]="リンク先が定義されていません"; 
$LANG['links'][9]="ファイルの内容"; 

$LANG['log'][1]="システム"; 
$LANG['log'][16]="予定表"; 
$LANG['log'][18]="PC内部パーツ"; 
$LANG['log'][20]="アイテムを追加"; 
$LANG['log'][21]="アイテムをアップデート"; 
$LANG['log'][22]="アイテムを削除"; 
$LANG['log'][23]="アイテムをリストア"; 
$LANG['log'][24]="アイテムを除く"; 
$LANG['log'][26]="接続してないアイテム"; 
$LANG['log'][27]="アイテムの接続"; 
$LANG['log'][28]="アップデートコンポーネント"; 
$LANG['log'][29]="ソリューションの承認/否承認"; 
$LANG['log'][30]="種別を結合"; 
$LANG['log'][31]="種別を削除"; 
$LANG['log'][32]="アイテムのリンク先を追加"; 
$LANG['log'][33]="アイテムのリンク先を削除"; 
$LANG['log'][34]="業種のリンク先を追加"; 
$LANG['log'][35]="業種のリンク先を削除"; 
$LANG['log'][40]="IP接続"; 
$LANG['log'][41]="接続失敗"; 
$LANG['log'][42]="予約"; 
$LANG['log'][44]="見出し"; 
$LANG['log'][45]="成功"; 
$LANG['log'][46]="失敗"; 
$LANG['log'][48]="グループにユーザを追加"; 
$LANG['log'][49]="グループからユーザを削除"; 
$LANG['log'][55]="接続"; 
$LANG['log'][59]="自動実行"; 
$LANG['log'][60]="このアイテムを単品管理する"; 
$LANG['log'][61]="ユーザーを追加する"; 
$LANG['log'][62]="このユーザを完全に削除する"; 
$LANG['log'][64]="フィールドの変更"; 
$LANG['log'][65]="ルール"; 
$LANG['log'][66]="セキュリティ"; 
$LANG['log'][67]="変更記録"; 
$LANG['log'][70]="ネットワークポートが追加された"; 
$LANG['log'][71]="数個のネットワークポートが追加された"; 
$LANG['log'][73]="ネットワークポートが削除された"; 
$LANG['log'][74]="数個のネットワークポートが削除された"; 
$LANG['log'][75]="ネットワークポートが移動された"; 
$LANG['log'][77]="VLANをネットワークポートに割り当て"; 
$LANG['log'][78]="VLANを数個のポートに割り当て"; 
$LANG['log'][79]="ネットワークポートに割り当てられていないVLAN"; 
$LANG['log'][80]="VLANを複数のネットワークポートから割り当て解除"; 
$LANG['log'][82]="バージョン追加"; 
$LANG['log'][83]="バージョン変更"; 
$LANG['log'][84]="隠蔽されたバージョン"; 
$LANG['log'][85]="ライセンス追加"; 
$LANG['log'][86]="ライセンス変更"; 
$LANG['log'][87]="隠蔽されたライセンス"; 
$LANG['log'][88]="カートリッジの追加"; 
$LANG['log'][89]="消耗品の追加"; 
$LANG['log'][90]="カートリッジの除去"; 
$LANG['log'][91]="消耗品の除去"; 
$LANG['log'][92]="カートリッジの返却"; 
$LANG['log'][93]="消耗品の返却"; 
$LANG['log'][94]="カートリッジ交換"; 
$LANG['log'][95]="カートリッジ新規取付"; 
$LANG['log'][96]="カートリッジのアンインストール"; 
$LANG['log'][97]="ユーザーが求める消耗品"; 
$LANG['log'][98]="項目の追加"; 
$LANG['log'][99]="アイテムの変更"; 
$LANG['log'][100]="アイテムの削除"; 

$LANG['login'][0]="最終ログイン"; 
$LANG['login'][1]="再ログイン"; 
$LANG['login'][2]="LDAPディレクトリ"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="アクセス禁止"; 
$LANG['login'][6]="ログイン"; 
$LANG['login'][7]="パスワード"; 
$LANG['login'][8]="ログイン名かパスワードが空です"; 
$LANG['login'][9]="認証されていません"; 
$LANG['login'][10]="認証"; 
$LANG['login'][11]="認証されていないユーザはGLPIに接続出来ません"; 
$LANG['login'][12]="ユーザー名もしくはパスワードが間違っています。"; 
$LANG['login'][13]="パスワード欄が空白です。"; 
$LANG['login'][14]="不明なユーザー"; 
$LANG['login'][15]="ユーザーが見つからないか、複数のユーザーが該当します。"; 
$LANG['login'][16]="LDAPでの権限付与に失敗しました"; 
$LANG['login'][18]="内部GLPIベース"; 
$LANG['login'][20]="アカウントが無効化もしくは削除されたため、このアプリケーションにアクセスできません。"; 
$LANG['login'][21]="IMAP/POP serverへのテスト接続"; 
$LANG['login'][22]="テスト成功"; 
$LANG['login'][23]="テスト失敗"; 
$LANG['login'][24]="最終ログイン日"; 
$LANG['login'][25]="接続する権限がありません。"; 
$LANG['login'][26]="ブラウザでJavaScriptを有効にする必要があります。"; 
$LANG['login'][27]="このアプリケーションを使うにはクッキーを有効にする必要があります。"; 
$LANG['login'][30]="認証方法を変更する"; 
$LANG['login'][31]="LDAPディレクトリでの認証"; 
$LANG['login'][32]="GLPIデータベースにおける認証"; 
$LANG['login'][33]="IMAP/POPサーバにおける認証"; 

$LANG['mailgate'][0]="メール受信者"; 
$LANG['mailgate'][2]="今すぐメールチケットを取得"; 
$LANG['mailgate'][3]="有効な受信メールの数"; 
$LANG['mailgate'][4]="mbstring拡張が見つかりません。使用中の文字セットを確認して下さい。"; 
$LANG['mailgate'][5]="無効添付ファイル"; 
$LANG['mailgate'][6]="添付ファイルが大き過ぎます。"; 
$LANG['mailgate'][7]="メール受信者がインポートする各ファイルの最大サイズ"; 
$LANG['mailgate'][9]="E-mailは処理されない可能性があります。\n問題が継続する場合は管理者に相談して下さい。"; 
$LANG['mailgate'][10]="拒否されたE-mail"; 
$LANG['mailgate'][11]="E-mailインポート処理"; 
$LANG['mailgate'][12]="E-mailをエンティティに影響させることはできません"; 
$LANG['mailgate'][13]="拒絶理由"; 
$LANG['mailgate'][14]="E-mailが見つかりません。インポート不可"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="フォローアップを完了"; 
$LANG['mailing'][5]="チケットの内容"; 
$LANG['mailing'][10]="新しいチケットの対応内容"; 
$LANG['mailing'][12]="チケット担当者"; 
$LANG['mailing'][14]="チケットのカテゴリをアップデート"; 
$LANG['mailing'][15]="チケットの重要度をアップデート"; 
$LANG['mailing'][17]="チケットのアイテムをアップデート"; 
$LANG['mailing'][18]="チケット作成者を更新"; 
$LANG['mailing'][19]="新しい予約"; 
$LANG['mailing'][20]="チケットグループを更新"; 
$LANG['mailing'][21]="チケットソースを変更する"; 
$LANG['mailing'][23]="予約を編集"; 
$LANG['mailing'][26]="追加された文書"; 
$LANG['mailing'][27]="チケットのステータスをアップデート"; 
$LANG['mailing'][29]="予約を中止しました"; 
$LANG['mailing'][30]="チケットを アップデート"; 
$LANG['mailing'][31]="自動生成によるテストメールです"; 
$LANG['mailing'][32]="メールの確認"; 
$LANG['mailing'][33]="プリンタカートリッジのアラート"; 
$LANG['mailing'][35]="消耗品がアラート閾値以下になりました："; 
$LANG['mailing'][36]="消耗品のアラート"; 
$LANG['mailing'][37]="終了通知期間に入った契約："; 
$LANG['mailing'][39]="契約のアラート"; 
$LANG['mailing'][40]="アイテムの保証期限が切れました："; 
$LANG['mailing'][41]="財務情報のアラート"; 
$LANG['mailing'][42]="時間割費用を変更する"; 
$LANG['mailing'][43]="固定費を変更する"; 
$LANG['mailing'][44]="マテリアルコストを変更する"; 
$LANG['mailing'][45]="チケットタイトルを変更する"; 
$LANG['mailing'][46]="チケット詳細を変更する"; 
$LANG['mailing'][47]="送信メールエラー"; 
$LANG['mailing'][48]="開始日における変更"; 
$LANG['mailing'][49]="終了日における変更"; 
$LANG['mailing'][50]="チケット受信者の変更"; 
$LANG['mailing'][51]="期限切れライセンス："; 
$LANG['mailing'][53]="ソリューションの変更"; 
$LANG['mailing'][54]="失効日"; 
$LANG['mailing'][100]="カテゴリが定義されていません"; 
$LANG['mailing'][101]="E-mailフォロー有効"; 
$LANG['mailing'][102]="E-mailフォロー無効"; 
$LANG['mailing'][104]="経過時間"; 
$LANG['mailing'][105]="担当者が割り当てられていません"; 
$LANG['mailing'][107]="無し"; 
$LANG['mailing'][109]="グループ無し"; 
$LANG['mailing'][110]="無効なEメール"; 
$LANG['mailing'][113]="通知テンプレート"; 
$LANG['mailing'][114]="本文"; 
$LANG['mailing'][115]="E-mail本文"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="テキスト"; 
$LANG['mailing'][118]="E-mail"; 
$LANG['mailing'][119]="発生"; 
$LANG['mailing'][120]="通知方法"; 
$LANG['mailing'][121]="受信者"; 
$LANG['mailing'][122]="処理済みタスク"; 
$LANG['mailing'][123]="解決済みチケット"; 
$LANG['mailing'][124]="新しい変換を追加する"; 
$LANG['mailing'][125]="デフォルト変換"; 
$LANG['mailing'][126]="テンプレート変換"; 
$LANG['mailing'][127]="チケットのクローズ"; 
$LANG['mailing'][128]="HTMLからの生成時、フィールドは空にしておいて下さい"; 
$LANG['mailing'][129]="チケットの削除"; 
$LANG['mailing'][130]="から"; 
$LANG['mailing'][131]="受信者"; 
$LANG['mailing'][132]="E-mailヘッダー"; 
$LANG['mailing'][133]="E-mailを削除"; 
$LANG['mailing'][134]="更新フォローアップ"; 
$LANG['mailing'][135]="フォローアップの削除"; 
$LANG['mailing'][136]="予約の終了"; 
$LANG['mailing'][137]="ハードウェアユーザー"; 
$LANG['mailing'][138]="有効なタグのリスト"; 
$LANG['mailing'][139]="ラベル"; 
$LANG['mailing'][140]="タグ"; 
$LANG['mailing'][141]="フォローアップ"; 
$LANG['mailing'][142]="タスク"; 
$LANG['mailing'][143]="有効化"; 
$LANG['mailing'][144]="履歴"; 
$LANG['mailing'][145]="値のリスト"; 
$LANG['mailing'][146]="単独値"; 
$LANG['mailing'][147]="利用可能な値"; 

$LANG['Menu'][0]="コンピュータ"; 
$LANG['Menu'][1]="ネットワーク"; 
$LANG['Menu'][2]="プリンタ"; 
$LANG['Menu'][3]="モニタ"; 
$LANG['Menu'][4]="ソフトウエア"; 
$LANG['Menu'][5]="チケット"; 
$LANG['Menu'][6]="レポート"; 
$LANG['Menu'][11]="個人別設定"; 
$LANG['Menu'][12]="メンテナンス"; 
$LANG['Menu'][13]="ヘルプデスク統計"; 
$LANG['Menu'][14]="ユーザ"; 
$LANG['Menu'][15]="設定"; 
$LANG['Menu'][16]="周辺機器"; 
$LANG['Menu'][17]="貸し出し品の予約"; 
$LANG['Menu'][18]="ツール"; 
$LANG['Menu'][19]="ナレッジベース"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="プリンタカートリッジ"; 
$LANG['Menu'][22]="アドレス帳"; 
$LANG['Menu'][23]="メーカ"; 
$LANG['Menu'][24]="会計情報"; 
$LANG['Menu'][25]="契約情報管理"; 
$LANG['Menu'][26]="運営管理"; 
$LANG['Menu'][27]="ドキュメント"; 
$LANG['Menu'][28]="ステータス"; 
$LANG['Menu'][29]="予定表"; 
$LANG['Menu'][30]="ログ"; 
$LANG['Menu'][31]="シンプルインターフェイス"; 
$LANG['Menu'][32]="消耗品"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="電話"; 
$LANG['Menu'][35]="プロファイル"; 
$LANG['Menu'][36]="グループ"; 
$LANG['Menu'][37]="エンティティ"; 
$LANG['Menu'][38]="一覧"; 
$LANG['Menu'][39]="メール受信者"; 
$LANG['Menu'][40]="ブックマーク"; 
$LANG['Menu'][41]="権限"; 

$LANG['monitors'][14]="マイク"; 
$LANG['monitors'][15]="スピーカー"; 
$LANG['monitors'][18]="フラグ"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="サイズ"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="ピボット"; 

$LANG['networking'][4]="ネットワークポート"; 
$LANG['networking'][5]="メモリ(MB)"; 
$LANG['networking'][6]="ネットワークポート"; 
$LANG['networking'][13]="ネットワーク情報が見付かりました"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="接続先"; 
$LANG['networking'][19]="ネットワーク情報を追加..."; 
$LANG['networking'][21]="ポート番号"; 
$LANG['networking'][25]="において"; 
$LANG['networking'][37]="ネットワークポートが見つかりました"; 
$LANG['networking'][44]="ポート"; 
$LANG['networking'][46]="複数のネットワーク情報を追加..."; 
$LANG['networking'][47]="From"; 
$LANG['networking'][48]="To"; 
$LANG['networking'][51]="ネットワークポイント"; 
$LANG['networking'][55]="VLANに追加"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="MACアドレスを追加"; 
$LANG['networking'][58]="VLANを解除"; 
$LANG['networking'][59]="ゲートウェイ"; 
$LANG['networking'][60]="マスク"; 
$LANG['networking'][61]="サブネット"; 

$LANG['ocsconfig'][1]="OCSNGデータベースユーザー"; 
$LANG['ocsconfig'][2]="OCSNGデータベースホスト名"; 
$LANG['ocsconfig'][3]="OCSNGユーザーパスワード"; 
$LANG['ocsconfig'][4]="OCSNGデータベース名"; 
$LANG['ocsconfig'][5]="インポートのオプション"; 
$LANG['ocsconfig'][6]="OCSNGインポートでは無視"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="以下のタグは除外します。（区切り文字は＄で、＄自体は意味を持ちません）"; 
$LANG['ocsconfig'][10]="グローバルインポート"; 
$LANG['ocsconfig'][11]="インポート無し"; 
$LANG['ocsconfig'][12]="ユニットインポート"; 
$LANG['ocsconfig'][13]="ユニットインポート：インポート元を変更しない"; 
$LANG['ocsconfig'][14]="グローバルインポート：everything is imported but the material is globally managed （without double blooms）"; 
$LANG['ocsconfig'][15]="インポート無し：プラグインはデータエレメントをインポートしません"; 
$LANG['ocsconfig'][16]="初期値"; 
$LANG['ocsconfig'][17]="以下のタグだけをインポートします（区切り文字は＄で、＄自体は意味を持ちません）"; 
$LANG['ocsconfig'][18]="はじめにOCSNG側で管理している内容の重複をチェックして下さい"; 
$LANG['ocsconfig'][19]="シリアルナンバーにおけるユニットインポート"; 
$LANG['ocsconfig'][27]="一般情報"; 
$LANG['ocsconfig'][36]="モデム"; 
$LANG['ocsconfig'][37]="ポート"; 
$LANG['ocsconfig'][38]="OCSNGソフトウェアリストを使用"; 
$LANG['ocsconfig'][39]="OCSNGサーバー"; 
$LANG['ocsconfig'][40]="OCSNG自動実行で同期するアイテム数"; 
$LANG['ocsconfig'][41]="レジストリ"; 
$LANG['ocsconfig'][43]="OCSNG管理情報"; 
$LANG['ocsconfig'][48]="接続できない場合の挙動"; 
$LANG['ocsconfig'][49]="ゴミ箱に入れる"; 
$LANG['ocsconfig'][50]="消去"; 
$LANG['ocsconfig'][52]="機器の自動接続"; 
$LANG['ocsconfig'][53]="自動リンクを有効に"; 
$LANG['ocsconfig'][54]="現存するコンピュータの範囲"; 
$LANG['ocsconfig'][55]="ステータスを持つコンピュータを検索"; 
$LANG['ocsconfig'][56]="空白"; 
$LANG['ocsconfig'][57]="同等"; 
$LANG['ocsconfig'][58]="リンクによりGLPIのコンピュータは自動的にOCSNG内のそれと接続されます。<br>このオプションは手動リンク中でかつ同期スクリプトによる場合のみ選択可能です。"; 
$LANG['ocsconfig'][59]="OCSNGコンソールのURL"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="インポートされたコンピュータを同期"; 
$LANG['ocsng'][2]="新しいコンピュータをインポート"; 
$LANG['ocsng'][3]="GLPI-OCSNG間のリンクを整理"; 
$LANG['ocsng'][4]="現行のGLPIコンピュータに新しいOCSコンピュータをリンクする"; 
$LANG['ocsng'][5]="新しいコンピュータをインポート"; 
$LANG['ocsng'][6]="自動更新"; 
$LANG['ocsng'][7]="OCSNGからインポートしました"; 
$LANG['ocsng'][8]="インポートに成功しました"; 
$LANG['ocsng'][9]="新しくインポートされたコンピュータはありません"; 
$LANG['ocsng'][10]="コンピュータをOCSNGに更新"; 
$LANG['ocsng'][11]="コンピュータをアップデート"; 
$LANG['ocsng'][12]="新しく更新されたコンピュータはありません"; 
$LANG['ocsng'][13]="GLPIにインポートされた日付"; 
$LANG['ocsng'][14]="前回のOCSNG一覧日付"; 
$LANG['ocsng'][15]="フィールドがロックされていません"; 
$LANG['ocsng'][16]="フィールドがロックされています"; 
$LANG['ocsng'][18]="OCSNGデータベースへの接続に成功"; 
$LANG['ocsng'][19]="有効なOCSNGの設定及びバージョン"; 
$LANG['ocsng'][20]="無効なOCSNGバージョン（RC3が必要）"; 
$LANG['ocsng'][21]="OCSNGデータベースへの接続に失敗"; 
$LANG['ocsng'][22]="注意：データをインポートすると上書きされます"; 
$LANG['ocsng'][23]="インポートできません。GLPIコンピュータはすでにOCSNGの要素と関連付けられています。"; 
$LANG['ocsng'][24]="強制同期"; 
$LANG['ocsng'][26]="OCSNGサーバの選択"; 
$LANG['ocsng'][27]="OCSNGサーバが定義されていません"; 
$LANG['ocsng'][29]="OCSNG名"; 
$LANG['ocsng'][30]="ロックされたモニター"; 
$LANG['ocsng'][32]="ロックされたデバイス"; 
$LANG['ocsng'][34]="ロックされたプリンター"; 
$LANG['ocsng'][36]="相手先"; 
$LANG['ocsng'][37]="プレビューを有効にする"; 
$LANG['ocsng'][38]="プレビューできない"; 
$LANG['ocsng'][40]="ルールに適合していますか？"; 
$LANG['ocsng'][41]="手動インポートモード"; 
$LANG['ocsng'][42]="無効なOCSNG構成 (TRACE_DELETED を有効にして下さい)"; 
$LANG['ocsng'][43]="OCSNGデータベースでのアクセスは拒否されました（ハードウェア書き込み及びチェックサム権限が必要）"; 
$LANG['ocsng'][44]="OCSNGデータベースでのアクセスは拒否されました（deleted_equivテーブルに対して削除権限が必要）"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="OCSNGから削除された"; 
$LANG['ocsng'][47]="OCSNGコンピュータとのリンク"; 
$LANG['ocsng'][48]="コンピュータのOCSNG IDが変更されました。"; 
$LANG['ocsng'][49]="エージェント"; 
$LANG['ocsng'][50]="ロックされたIP"; 
$LANG['ocsng'][52]="ロックされたソフトウェア"; 
$LANG['ocsng'][54]="OCSNG同期によって削除されたソフトウェア"; 
$LANG['ocsng'][55]="ロックされた領域"; 
$LANG['ocsng'][57]="OCSNG インターフェイス"; 

$LANG['pager'][1]="to"; 
$LANG['pager'][2]="from"; 
$LANG['pager'][3]="in"; 
$LANG['pager'][4]="表示"; 
$LANG['pager'][5]="アイテム"; 

$LANG['peripherals'][18]="メーカ"; 
$LANG['peripherals'][31]="グローバル管理"; 
$LANG['peripherals'][32]="ユニット管理"; 
$LANG['peripherals'][33]="管理種別"; 

$LANG['phones'][18]="メーカ"; 
$LANG['phones'][36]="電源ユニット"; 
$LANG['phones'][38]="ヘッドフォン"; 
$LANG['phones'][39]="スピーカー"; 
$LANG['phones'][40]="回線数"; 

$LANG['planning'][0]="この技術者に既に予定が入っているため計画を登録出来ません"; 
$LANG['planning'][1]="日付を確認して下さい"; 
$LANG['planning'][5]="日"; 
$LANG['planning'][6]="週"; 
$LANG['planning'][8]="対応状況"; 
$LANG['planning'][9]="担当者"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Icalフォーマットで予定表をダウンロード"; 
$LANG['planning'][13]="webcal：// Synchronization"; 
$LANG['planning'][14]="月"; 
$LANG['planning'][15]="予定表"; 
$LANG['planning'][16]="インフォメーション"; 
$LANG['planning'][17]="ToDo"; 
$LANG['planning'][18]="完了"; 

$LANG['plugins'][0]="プラグインのリスト"; 
$LANG['plugins'][2]="インストール済　/　未設定"; 
$LANG['plugins'][3]="インストール済　/　未起動"; 
$LANG['plugins'][4]="エラー　/　要クリーニング"; 
$LANG['plugins'][5]="存在しない機能"; 
$LANG['plugins'][6]="更新するには"; 
$LANG['plugins'][7]="インストールされたプラグインなし"; 
$LANG['plugins'][8]="プラグイン一覧を参照"; 
$LANG['plugins'][9]="著作者"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="シリアル"; 
$LANG['printers'][15]="パラレル"; 
$LANG['printers'][18]="ポート"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="イーサネット"; 
$LANG['printers'][29]="Wi-Fi"; 
$LANG['printers'][30]="ページカウンター開始番号"; 
$LANG['printers'][31]="印刷された枚数"; 

$LANG['profiles'][0]="グローバル権限"; 
$LANG['profiles'][1]="エンティティ権限"; 
$LANG['profiles'][2]="プロフィールのインターフェイス"; 
$LANG['profiles'][4]="自グループのチケットにフォローアップを追加する"; 
$LANG['profiles'][5]="チケットを作成"; 
$LANG['profiles'][6]="チケット（発行者）へのフォローアップを追加"; 
$LANG['profiles'][7]="全てのチケットを表示"; 
$LANG['profiles'][8]="全てのフォローアップとタスク（公私とも）を見る"; 
$LANG['profiles'][9]="公開されているフォローアップとタスクを表示"; 
$LANG['profiles'][10]="読み込む"; 
$LANG['profiles'][11]="書き込む"; 
$LANG['profiles'][12]="アクセスがありません"; 
$LANG['profiles'][13]="デフォルトのプロフィール"; 
$LANG['profiles'][14]="チケットを削除する"; 
$LANG['profiles'][15]="全てのチケットへのフォローアップを追加する"; 
$LANG['profiles'][16]="チケットを管理するため"; 
$LANG['profiles'][17]="チケットを盗用する"; 
$LANG['profiles'][18]="チケットを更新する"; 
$LANG['profiles'][19]="チケットを割り当てる"; 
$LANG['profiles'][20]="個人の計画を見る"; 
$LANG['profiles'][21]="全ての計画を見る"; 
$LANG['profiles'][22]="プロフィール"; 
$LANG['profiles'][23]="管理者固有の権限"; 
$LANG['profiles'][24]="パスワードを更新する"; 
$LANG['profiles'][26]="グループが作成したチケットを表示"; 
$LANG['profiles'][27]="自グループのハードウェアを参照"; 
$LANG['profiles'][28]="反復的な"; 
$LANG['profiles'][29]="動的な"; 
$LANG['profiles'][30]="OCSNG情報を見る"; 
$LANG['profiles'][31]="OCSNGの手動同期"; 
$LANG['profiles'][32]="チケットを参照（個人＋グループ）"; 
$LANG['profiles'][33]="ユーザが見つかりません"; 
$LANG['profiles'][34]="キャプション"; 
$LANG['profiles'][35]="全てのフォローアップを更新する"; 
$LANG['profiles'][36]="自分のグループのメンバーのスケジュールを見る"; 
$LANG['profiles'][37]="デフォルトエンティティ"; 
$LANG['profiles'][38]="可視性"; 
$LANG['profiles'][39]="割り当て"; 
$LANG['profiles'][40]="更新"; 
$LANG['profiles'][41]="作成"; 
$LANG['profiles'][42]="関連付け"; 
$LANG['profiles'][43]="ユーザーの認証及び同期の方法"; 
$LANG['profiles'][44]="優先順位の変更"; 
$LANG['profiles'][45]="全てのチケットにタスクを追加する"; 
$LANG['profiles'][46]="全てのタスクを編集"; 
$LANG['profiles'][47]="外部からユーザーを追加"; 
$LANG['profiles'][48]="有効化依頼の作成"; 
$LANG['profiles'][49]="チケットを有効化"; 

$LANG['registry'][1]="ハイブ"; 
$LANG['registry'][2]="パス"; 
$LANG['registry'][3]="キー/値"; 
$LANG['registry'][4]="レジストリキーが見つかりました"; 
$LANG['registry'][5]="登録にキーが見つかりません"; 
$LANG['registry'][6]="OCSNG名"; 

$LANG['reminder'][0]="個人用メモ"; 
$LANG['reminder'][1]="共用メモ"; 
$LANG['reminder'][6]="新しいメモ"; 
$LANG['reminder'][9]="本文"; 
$LANG['reminder'][12]="予定表に追加"; 
$LANG['reminder'][15]="タイトル無し"; 
$LANG['reminder'][16]="グローバルノート"; 

$LANG['reports'][0]="レポートを選択"; 
$LANG['reports'][4]="契約中のハードウェア"; 
$LANG['reports'][11]="契約中のハードウェア"; 
$LANG['reports'][12]="ハードウェア種別"; 
$LANG['reports'][13]="日付"; 
$LANG['reports'][15]="ステータスを表示"; 
$LANG['reports'][19]="代替ユーザー名"; 
$LANG['reports'][26]="レポートの要約"; 
$LANG['reports'][27]="契約中のハードウェア"; 
$LANG['reports'][28]="年次"; 
$LANG['reports'][33]="ネットワーク情報"; 
$LANG['reports'][36]="接続された周辺機器"; 
$LANG['reports'][37]="Drops"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="場所"; 
$LANG['reports'][41]="ハードウェア単位"; 
$LANG['reports'][42]="drop"; 
$LANG['reports'][46]="ハードウェアポート"; 
$LANG['reports'][47]="周辺機器のポート"; 
$LANG['reports'][49]="ハードウェア単位のネットワーク情報"; 
$LANG['reports'][51]="ドロップ別のネットワーク情報"; 
$LANG['reports'][52]="スイッチ"; 
$LANG['reports'][54]="場所別のネットワーク情報"; 
$LANG['reports'][57]="機器一覧"; 
$LANG['reports'][58]="年次の機器レポート"; 
$LANG['reports'][60]="開始日付"; 
$LANG['reports'][61]="終了日"; 
$LANG['reports'][62]="ハードウェアポート"; 
$LANG['reports'][63]="その他の財務情報（ライセンス・カートリッジ・消耗品）"; 
$LANG['reports'][64]="解決日"; 

$LANG['reservation'][1]="貸し出し品"; 
$LANG['reservation'][2]="デバイスは一時的に利用できない"; 
$LANG['reservation'][3]="無効にする"; 
$LANG['reservation'][5]="有効にする"; 
$LANG['reservation'][6]="予約を禁止する"; 
$LANG['reservation'][7]="予約を許可"; 
$LANG['reservation'][8]="予約"; 
$LANG['reservation'][9]="アイテムを予約"; 
$LANG['reservation'][16]="To"; 
$LANG['reservation'][17]="From"; 
$LANG['reservation'][18]="既に予約が入っています"; 
$LANG['reservation'][20]="計画に戻る"; 
$LANG['reservation'][21]="予約状況参照"; 
$LANG['reservation'][22]="備考を編集"; 
$LANG['reservation'][25]="全予約可能ハードウェア"; 
$LANG['reservation'][27]="リハーサル"; 
$LANG['reservation'][28]="週別"; 
$LANG['reservation'][29]="日別"; 
$LANG['reservation'][30]="times"; 
$LANG['reservation'][31]="貸し出し先担当者"; 
$LANG['reservation'][35]="現在の予約"; 
$LANG['reservation'][36]="以前の予約"; 
$LANG['reservation'][37]="予約無し"; 
$LANG['reservation'][38]="貸出一覧からこのアイテムを削除してもよろしいですか？"; 
$LANG['reservation'][39]="アイテムの予約も削除されます"; 
$LANG['reservation'][40]="機器予約は本日終了"; 

$LANG['rulesengine'][0]="である"; 
$LANG['rulesengine'][1]="でない"; 
$LANG['rulesengine'][2]="を含む"; 
$LANG['rulesengine'][3]="含んでいない"; 
$LANG['rulesengine'][4]="からはじめる"; 
$LANG['rulesengine'][5]="により終了"; 
$LANG['rulesengine'][6]="範囲"; 
$LANG['rulesengine'][7]="実行"; 
$LANG['rulesengine'][8]="ルールマネージメント"; 
$LANG['rulesengine'][9]="論理演算子"; 
$LANG['rulesengine'][10]="ポジション"; 
$LANG['rulesengine'][11]="実行タイプ"; 
$LANG['rulesengine'][12]="フィールド"; 
$LANG['rulesengine'][13]="値"; 
$LANG['rulesengine'][14]="状態"; 
$LANG['rulesengine'][15]="理由"; 
$LANG['rulesengine'][16]="範囲"; 
$LANG['rulesengine'][17]="ルール"; 
$LANG['rulesengine'][18]="エンティティへコンピュータを割り当てるルール"; 
$LANG['rulesengine'][19]="エンティティと権限に割り当てられたルール"; 
$LANG['rulesengine'][20]="適用されたルール"; 
$LANG['rulesengine'][21]="子エンティティのルール"; 
$LANG['rulesengine'][22]="割り当てる"; 
$LANG['rulesengine'][23]="ローカルルール"; 
$LANG['rulesengine'][24]="ルールタイプ"; 
$LANG['rulesengine'][25]="コンピュータ名"; 
$LANG['rulesengine'][26]="正規表現チェック"; 
$LANG['rulesengine'][27]="正規表現のアンマッチ"; 
$LANG['rulesengine'][28]="チケット取り扱いの業務ルール"; 
$LANG['rulesengine'][29]="リスト規則"; 
$LANG['rulesengine'][30]="実行"; 
$LANG['rulesengine'][33]="リストを開く"; 
$LANG['rulesengine'][35]="ソフトウェアリスト"; 
$LANG['rulesengine'][36]="デフォルトリスト"; 
$LANG['rulesengine'][37]="ソフトウェアへカテゴリーの割り当てのルール"; 
$LANG['rulesengine'][38]="再計算"; 
$LANG['rulesengine'][40]="そのカテゴリー"; 
$LANG['rulesengine'][41]="バリデーション"; 
$LANG['rulesengine'][42]="かつ"; 
$LANG['rulesengine'][43]="もしくは"; 
$LANG['rulesengine'][45]="正規表現から値を割り当て"; 
$LANG['rulesengine'][46]="割り当て：IPアドレス"; 
$LANG['rulesengine'][47]="割り当て：名前＋ドメイン"; 
$LANG['rulesengine'][48]="属性の割り当て"; 
$LANG['rulesengine'][49]="割り当て：MACアドレス"; 
$LANG['rulesengine'][50]="コンピュータモデルリスト"; 
$LANG['rulesengine'][51]="モニターモデルリスト"; 
$LANG['rulesengine'][52]="電話モデルリスト"; 
$LANG['rulesengine'][53]="周辺モデルリスト"; 
$LANG['rulesengine'][54]="プリンターモデルリスト"; 
$LANG['rulesengine'][55]="ネットワークモデルリスト"; 
$LANG['rulesengine'][56]="モデル"; 
$LANG['rulesengine'][60]="コンピュータタイプリスト"; 
$LANG['rulesengine'][61]="モニタータイプリスト"; 
$LANG['rulesengine'][62]="電話タイプリスト"; 
$LANG['rulesengine'][63]="周辺装置タイプリスト"; 
$LANG['rulesengine'][64]="プリンタータイプリスト"; 
$LANG['rulesengine'][65]="ネットワークデバイスタイプリスト"; 
$LANG['rulesengine'][66]="タイプ"; 
$LANG['rulesengine'][67]="OSリスト"; 
$LANG['rulesengine'][68]="サービスパックリスト"; 
$LANG['rulesengine'][69]="OSバージョンリスト"; 
$LANG['rulesengine'][70]="メール受信者が作成したチケットを割り当てるルール"; 
$LANG['rulesengine'][76]="リストを再現する"; 
$LANG['rulesengine'][77]="リスト"; 
$LANG['rulesengine'][78]="バージョン"; 
$LANG['rulesengine'][79]="正規表現の結果を追加"; 
$LANG['rulesengine'][80]="グローバルリスト"; 
$LANG['rulesengine'][81]="ルール結果"; 
$LANG['rulesengine'][82]="結果詳細"; 
$LANG['rulesengine'][83]="文字列#0を使った正規表現の結果に影響を及ぼす"; 
$LANG['rulesengine'][84]="テストルールエンジン"; 
$LANG['rulesengine'][85]="正規表現の結果"; 
$LANG['rulesengine'][86]="ソフトウェアがリストから削除されたとき影響を受けるソフトウェアカテゴリー"; 
$LANG['rulesengine'][87]="GLPIリストによって削除されたソフトウェア"; 
$LANG['rulesengine'][90]="作業中…"; 
$LANG['rulesengine'][91]="作業終了"; 
$LANG['rulesengine'][92]="リストを走らせる前に警告する"; 
$LANG['rulesengine'][93]="警告！この操作はソフトウェアを削除する可能性があります。必ずユーザーに伝えて下さい。"; 
$LANG['rulesengine'][94]="フュージョン"; 
$LANG['rulesengine'][95]="デフォルト選択"; 
$LANG['rulesengine'][96]="デフォルトリストを再現する。( ----- = 全て)"; 
$LANG['rulesengine'][97]="テストされる要素はありません。"; 
$LANG['rulesengine'][100]="キャッシュ情報"; 
$LANG['rulesengine'][102]="ルール名"; 
$LANG['rulesengine'][103]="キャッシュ中のオブジェクト"; 
$LANG['rulesengine'][104]="元の値"; 
$LANG['rulesengine'][105]="修正された値"; 
$LANG['rulesengine'][106]="未変更"; 
$LANG['rulesengine'][107]="無効"; 
$LANG['rulesengine'][108]="元の"; 
$LANG['rulesengine'][110]="権限の割り当て"; 
$LANG['rulesengine'][111]="エンティティ割り当て"; 
$LANG['rulesengine'][112]="権限とエンティティの割り当て"; 
$LANG['rulesengine'][120]="エンジンは、最初にチェックされたルールで停止します。"; 
$LANG['rulesengine'][121]="エンジンは、全てのルールを処理します。"; 
$LANG['rulesengine'][122]="エンジンは、次の事柄に対するルールの結果を承認します。"; 
$LANG['rulesengine'][130]="LDAPからのエンティティ"; 
$LANG['rulesengine'][131]="TAGからのエンティティ"; 
$LANG['rulesengine'][132]="インポートを意識しないためには"; 
$LANG['rulesengine'][133]="ドメインからのエンティティ"; 
$LANG['rulesengine'][134]="メール受信を拒否（応答しない）"; 
$LANG['rulesengine'][135]="メール受信を拒否（応答はする）"; 
$LANG['rulesengine'][138]="LDAP条件"; 
$LANG['rulesengine'][140]="抽出条件の追加"; 
$LANG['rulesengine'][142]="インポートされていないE-mailのリスト"; 
$LANG['rulesengine'][144]="ユーザープロフィールに基づくエンティティ"; 
$LANG['rulesengine'][145]="単一プロフィールのユーザー"; 
$LANG['rulesengine'][146]="プロファイルで規定されたユーザー"; 
$LANG['rulesengine'][147]="単一プロファイルで規定されたユーザー"; 
$LANG['rulesengine'][148]="メールドメインが公開されている"; 
$LANG['rulesengine'][150]="エンティティに影響するルールは無効化されています。"; 

$LANG['search'][0]="検索"; 
$LANG['search'][1]="全て"; 
$LANG['search'][2]="含む"; 
$LANG['search'][4]="ソート"; 
$LANG['search'][8]="開始日付"; 
$LANG['search'][9]="終了日付"; 
$LANG['search'][10]="において"; 
$LANG['search'][11]="アイテムが見付かりました"; 
$LANG['search'][12]="終了日通知"; 
$LANG['search'][15]="アイテムが見付かりませんでした"; 
$LANG['search'][16]="≧"; 
$LANG['search'][17]="検索条件を追加"; 
$LANG['search'][18]="検索条件を削除"; 
$LANG['search'][19]="グローバル検索条件を追加"; 
$LANG['search'][20]="グローバル検索条件を追加"; 

$LANG['setup'][0]="ドロップダウン"; 
$LANG['setup'][2]="GLPIユーザを追加"; 
$LANG['setup'][3]="LDAPディレクトリリンク"; 
$LANG['setup'][4]="コンピュータ種別"; 
$LANG['setup'][5]="オペレーティングシステム"; 
$LANG['setup'][6]="個人設定"; 
$LANG['setup'][9]="ネットワークインターフェース"; 
$LANG['setup'][10]="姓と名の表示順序"; 
$LANG['setup'][14]="E-Mail"; 
$LANG['setup'][18]="ログイン"; 
$LANG['setup'][19]="パスワード"; 
$LANG['setup'][20]="パスワードの確認"; 
$LANG['setup'][21]="エラー：パスワードが一致しません"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="デフォルトで非公開とされた"; 
$LANG['setup'][40]="デフォルトで非公開タスク"; 
$LANG['setup'][41]="言語を選択"; 
$LANG['setup'][42]="ネットワーク種別"; 
$LANG['setup'][43]="プリンタ種別"; 
$LANG['setup'][44]="モニタ種別"; 
$LANG['setup'][45]="ケース種別"; 
$LANG['setup'][46]="デフォルト値"; 
$LANG['setup'][47]="デフォルトチャート書式"; 
$LANG['setup'][48]="デフォルト値"; 
$LANG['setup'][62]="設定するカテゴリーを選択"; 
$LANG['setup'][63]="注意：アイテムの見出しを削除します"; 
$LANG['setup'][64]="見出しを使用しているアイテムを削除するとフィールドは空になります"; 
$LANG['setup'][65]="見出しを上書き出来ます："; 
$LANG['setup'][67]="外部認証"; 
$LANG['setup'][69]="周辺機器種別"; 
$LANG['setup'][70]="一般設定"; 
$LANG['setup'][71]="ファームウエア"; 
$LANG['setup'][73]="ネットワークポイント"; 
$LANG['setup'][74]="そのプレースはサブプレースを持っているため削除できません。"; 
$LANG['setup'][75]="子オブジェクト"; 
$LANG['setup'][79]="チケットのカテゴリー"; 
$LANG['setup'][80]="供給形態"; 
$LANG['setup'][81]="文書の見出し"; 
$LANG['setup'][82]="連絡先種別"; 
$LANG['setup'][83]="アイテムステータス"; 
$LANG['setup'][84]="カートリッジ 種別"; 
$LANG['setup'][85]="契約種別"; 
$LANG['setup'][86]="メモリ種別"; 
$LANG['setup'][87]="ナレッジベースカテゴリー"; 
$LANG['setup'][88]="ネットワーク"; 
$LANG['setup'][89]="ドメイン"; 
$LANG['setup'][90]="VLAN"; 
$LANG['setup'][91]="コンピュータモデル"; 
$LANG['setup'][92]="消耗品種別"; 
$LANG['setup'][93]="ハードディスクインターフェース"; 
$LANG['setup'][94]="モニタ モデル"; 
$LANG['setup'][95]="ネットワーク モデル"; 
$LANG['setup'][96]="プリンタ モデル"; 
$LANG['setup'][97]="周辺機器モデル"; 
$LANG['setup'][98]="タスクカテゴリー"; 
$LANG['setup'][99]="ビルド番号"; 
$LANG['setup'][100]="部屋番号"; 
$LANG['setup'][101]="自動実行タスクの最大数（CLI動作）"; 
$LANG['setup'][102]="ログレベル"; 
$LANG['setup'][103]="①　致命的（ログインエラーのみ）"; 
$LANG['setup'][104]="②　危険（使用していません）"; 
$LANG['setup'][105]="③　重大（成功したログインを含む）"; 
$LANG['setup'][106]="④　通知（追加・削除・進捗）"; 
$LANG['setup'][107]="⑤　完了（全て）"; 
$LANG['setup'][109]="ログの保存期間（日数、0は無制限）"; 
$LANG['setup'][110]="ホーム画面に新しいチケットを表示"; 
$LANG['setup'][111]="一ページに表示される最大検索結果数"; 
$LANG['setup'][112]="ドロップダウンにおける各アイテムの最大文字数"; 
$LANG['setup'][113]="標準言語"; 
$LANG['setup'][114]="重要度の色"; 
$LANG['setup'][115]="消耗品の閾値の初期値"; 
$LANG['setup'][116]="技術責任者にチケットを自動割り当て"; 
$LANG['setup'][117]="FAQの読み取り制限をしない"; 
$LANG['setup'][118]="ログイン画面の文章"; 
$LANG['setup'][119]="画面"; 
$LANG['setup'][120]="ドロップダウンとテキストボックスでAjaxを使用"; 
$LANG['setup'][121]="ドロップダウンの完全表示を行う文字（ワイルドカード）"; 
$LANG['setup'][122]="ワイルドカードを使用しないときドロップダウンに表示される最大アイテム数"; 
$LANG['setup'][123]="未満のアイテム数ならAjaxを使用しない"; 
$LANG['setup'][124]="外部認証元のユーザを自動追加"; 
$LANG['setup'][125]="外部ソースから…"; 
$LANG['setup'][126]="外部元のユーザを自動追加"; 
$LANG['setup'][127]="テキストボックスのオートコンプリート"; 
$LANG['setup'][128]="日付形式"; 
$LANG['setup'][129]="GLPI　IDを表示"; 
$LANG['setup'][130]="実行ログの保存日数"; 
$LANG['setup'][132]="ドロップダウンに完全な名前を表示する"; 
$LANG['setup'][133]="OCSNGモードを有効にする"; 
$LANG['setup'][134]="OCSNGモード"; 
$LANG['setup'][135]="標準"; 
$LANG['setup'][136]="変換"; 
$LANG['setup'][137]="Debug"; 
$LANG['setup'][138]="GLPIモード"; 
$LANG['setup'][139]="Common"; 
$LANG['setup'][140]="種別"; 
$LANG['setup'][145]="OS"; 
$LANG['setup'][147]="Ajax"; 
$LANG['setup'][148]="しばらく進める"; 
$LANG['setup'][149]="数値で表した数"; 
$LANG['setup'][150]="数値フォーマット"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn （for non anonymous binds）"; 
$LANG['setup'][156]="Pass （for non-anonymous binds）"; 
$LANG['setup'][157]="PHPにLDAPがインストールされていません"; 
$LANG['setup'][158]="外部接続元でLDAPを使用出来ません"; 
$LANG['setup'][159]="接続フィルター"; 
$LANG['setup'][162]="IMAP/POP設定"; 
$LANG['setup'][164]="IMAP/POPホスト名（ユーザのE-mailアドレスはlogin@thishost形式）"; 
$LANG['setup'][165]="PHPにIMAPがインストールされていません"; 
$LANG['setup'][166]="外部認証元でIMAP/POPで接続出来ません"; 
$LANG['setup'][167]="LDAPディレクトリ/GLPIリンク"; 
$LANG['setup'][168]="接続オプション"; 
$LANG['setup'][169]="メールフォルダー（任意、多くの場合「受信トレイ」）"; 
$LANG['setup'][170]="接続文字列"; 
$LANG['setup'][171]="ポート（任意）"; 
$LANG['setup'][172]="ポート（デフォルト=389）"; 
$LANG['setup'][174]="CASホスト"; 
$LANG['setup'][175]="ポート"; 
$LANG['setup'][176]="Rootディレクトリー（任意）"; 
$LANG['setup'][177]="CAS設定"; 
$LANG['setup'][178]="PHPにCURLもしくはDOMXMLがインストールされていません"; 
$LANG['setup'][179]="外部接続元でCASを使用出来ません"; 
$LANG['setup'][180]="TLSを使用"; 
$LANG['setup'][181]="ldap_start_tlsが見付かりませんでした"; 
$LANG['setup'][182]="代替URLからログアウト"; 
$LANG['setup'][185]="ファイルに格納されるログ (SQL, Email, 自動実行...)"; 
$LANG['setup'][186]="タイムゾーン"; 
$LANG['setup'][190]="x509認証"; 
$LANG['setup'][191]="x509メール属性"; 
$LANG['setup'][192]="有効"; 
$LANG['setup'][193]="_SERVER アレイ内でログインを保持する領域"; 
$LANG['setup'][194]="LDAPリストからの付加情報の検索"; 
$LANG['setup'][195]="ステータスを保存する"; 
$LANG['setup'][196]="ステータスをクリア"; 
$LANG['setup'][197]="コンピュータのステータスをコピーする"; 
$LANG['setup'][198]="ステータスを設定する"; 
$LANG['setup'][199]="login@domain形式でのログインでdomain部分を除去"; 
$LANG['setup'][200]="無制限"; 
$LANG['setup'][201]="警告とE-mailフォローアップの設定"; 
$LANG['setup'][202]="E-mailによるフォローアップ機能を有効にする"; 
$LANG['setup'][203]="管理者E-mailアドレス"; 
$LANG['setup'][204]="E-mail署名"; 
$LANG['setup'][205]="管理者へE-mail送信"; 
$LANG['setup'][206]="管理者へのE-mail送信に失敗しました"; 
$LANG['setup'][207]="メールへの管理者の返信（必要な場合）"; 
$LANG['setup'][217]="PHP Mailが無効もしくは不明です"; 
$LANG['setup'][218]="SMTPが必要です"; 
$LANG['setup'][219]="チケット作成にアクセス制限を行わない（ヘルプデスク・受信者）"; 
$LANG['setup'][221]="会計年度期首"; 
$LANG['setup'][223]="予定表のためのスケジュール制限"; 
$LANG['setup'][227]="アプリケーションのURL"; 
$LANG['setup'][228]="ログインフィールド"; 
$LANG['setup'][229]="管理者へテストメールを送信"; 
$LANG['setup'][231]="メール送信にSMTPサーバを使用"; 
$LANG['setup'][232]="SMTPホスト"; 
$LANG['setup'][234]="SMTPログイン名（任意）"; 
$LANG['setup'][235]="SMTPパスワード（任意）"; 
$LANG['setup'][236]="チケットの元担当者"; 
$LANG['setup'][237]="管理者"; 
$LANG['setup'][239]="チケットの担当者"; 
$LANG['setup'][240]="通知オプション"; 
$LANG['setup'][241]="個人パラメータがありません。個人パラメータを作成しますか？"; 
$LANG['setup'][242]="アラートオプション"; 
$LANG['setup'][243]="消耗品関連"; 
$LANG['setup'][244]="カートリッジ関連"; 
$LANG['setup'][245]="リマインダーの頻度"; 
$LANG['setup'][246]="契約に関する警告"; 
$LANG['setup'][247]="財務情報関連"; 
$LANG['setup'][248]="チケットを管理しているグループ"; 
$LANG['setup'][249]="リクエストグループ"; 
$LANG['setup'][250]="検索画面表示設定"; 
$LANG['setup'][252]="標準で表示するアイテムを選択"; 
$LANG['setup'][253]="グループ検索のフィルター"; 
$LANG['setup'][254]="検索タイプ"; 
$LANG['setup'][255]="そのユーザのグループ属性"; 
$LANG['setup'][256]="ユーザに"; 
$LANG['setup'][257]="グループに"; 
$LANG['setup'][258]="ユーザとグループ"; 
$LANG['setup'][259]="グループに所属"; 
$LANG['setup'][260]="そのグループのユーザ属性"; 
$LANG['setup'][261]="グループDN"; 
$LANG['setup'][262]="検索にDNを使う"; 
$LANG['setup'][263]="ユーザのためのフィルターを検索"; 
$LANG['setup'][264]="期限切れライセンスの警告"; 
$LANG['setup'][271]="モニター設定の変更を制限する"; 
$LANG['setup'][272]="デバイス設定の変更を制限する"; 
$LANG['setup'][273]="電話設定の変更を制限する"; 
$LANG['setup'][274]="手動での追加"; 
$LANG['setup'][275]="プリンタ設定の変更を制限する"; 
$LANG['setup'][280]="コンピュータに関連する要素の自動更新"; 
$LANG['setup'][281]="接続/更新時"; 
$LANG['setup'][282]="切断時"; 
$LANG['setup'][283]="コピー"; 
$LANG['setup'][284]="クリアする"; 
$LANG['setup'][285]="複製禁止"; 
$LANG['setup'][286]="削除禁止"; 
$LANG['setup'][300]="バージョンを確認"; 
$LANG['setup'][301]="新しいバージョンがあります："; 
$LANG['setup'][302]="GLPIプロジェクト公式サイトで入手できます。"; 
$LANG['setup'][303]="最新バージョンです"; 
$LANG['setup'][304]="接続に失敗しました。プロキシを使用している場合は設定を確認して下さい。"; 
$LANG['setup'][305]="毎日"; 
$LANG['setup'][306]="アップグレードを確認"; 
$LANG['setup'][307]="無効"; 
$LANG['setup'][308]="毎週"; 
$LANG['setup'][309]="毎月"; 
$LANG['setup'][310]="サイトに接続できませせん。"; 
$LANG['setup'][311]="Proxyサーバへの接続に失敗しました"; 
$LANG['setup'][312]="ウェブサイトには有効なデータはありません。"; 
$LANG['setup'][313]="注意：デフォルト値ではありません"; 
$LANG['setup'][350]="チケット作成時にアイテムを関連付けます"; 
$LANG['setup'][351]="全てのアイテム"; 
$LANG['setup'][352]="チケットに関連付けられるアイテム"; 
$LANG['setup'][360]="自動フィールド（*でマーク）"; 
$LANG['setup'][400]="Proxy設定"; 
$LANG['setup'][407]="シンプルインターフェイスのヘルプリンク"; 
$LANG['setup'][408]="標準インターフェイスのヘルプリンク"; 
$LANG['setup'][409]="チケットにドキュメントが追加されたときのデフォルト見出し"; 
$LANG['setup'][503]="電話モデル"; 
$LANG['setup'][504]="電話種別"; 
$LANG['setup'][505]="電話の電源ユニット種別"; 
$LANG['setup'][601]="LDAPの値"; 
$LANG['setup'][602]="OCSNG データベースへ接続"; 
$LANG['setup'][603]="ユーザを追加"; 
$LANG['setup'][604]="グループに関連付けます"; 
$LANG['setup'][606]="追加できません。そのユーザーはすでに存在します。"; 
$LANG['setup'][607]="プロフィールを共有する"; 
$LANG['setup'][608]="デフォルトでチケットに関連付けられるソフトウェア"; 
$LANG['setup'][609]="追加できません。OCSNGサーバは既に存在します。"; 
$LANG['setup'][610]="チケット必須タイトル"; 
$LANG['setup'][611]="チケット必須項目"; 
$LANG['setup'][612]="必須のチケットカテゴリ"; 
$LANG['setup'][613]="権限のないユーザーをLDAPディレクトリから追加"; 
$LANG['setup'][614]="ログインを更新できません。ユーザーは既に存在します。"; 
$LANG['setup'][615]="チケットの有効期間"; 
$LANG['setup'][616]="から \ へ"; 
$LANG['setup'][620]="リンク"; 
$LANG['setup'][621]="エンティティ検索フィルター"; 
$LANG['setup'][622]="代表的なエンティティを属性付ける"; 
$LANG['setup'][623]="LDAPディレクトリからエンティティをインポート"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="メールサーバー"; 
$LANG['setup'][661]="通知を設定できません。Email通知を有効にして下さい。"; 
$LANG['setup'][703]="一般設定"; 
$LANG['setup'][704]="通知"; 
$LANG['setup'][707]="予約に関する警報"; 
$LANG['setup'][708]="未解決チケットに関する警報"; 
$LANG['setup'][720]="システム情報"; 
$LANG['setup'][721]="システムのインストールと設定の情報"; 
$LANG['setup'][722]="サポート依頼にコピー/貼り付けするには"; 
$LANG['setup'][731]="グローバル設定の値"; 
$LANG['setup'][732]="E-mailサービスのドメイン"; 
$LANG['setup'][800]="MySQL 複製"; 
$LANG['setup'][801]="MySQLの複製を可能にする"; 
$LANG['setup'][802]="データベース"; 
$LANG['setup'][803]="マスターとスレイブとの相違"; 
$LANG['setup'][806]="マスタースレイブ間の最大遅延（分）"; 
$LANG['setup'][807]="スレイブデータベースは同期していません。相違点は以下の通り:"; 
$LANG['setup'][808]="スレイブデータベースが同期していません！"; 
$LANG['setup'][809]="MySQL 複製: 読み取り専用"; 
$LANG['setup'][810]="同期切れMySQLの複製"; 

$LANG['software'][1]="購入版"; 
$LANG['software'][2]="使用バージョン"; 
$LANG['software'][3]="ライセンスに影響を与えるインストールなし"; 
$LANG['software'][4]="無制限"; 
$LANG['software'][5]="バージョン"; 
$LANG['software'][6]="発行者"; 
$LANG['software'][7]="バージョンを追加する"; 
$LANG['software'][8]="ライセンスを追加する"; 
$LANG['software'][11]="ライセンス"; 
$LANG['software'][17]="インストールされているソフトウエア"; 
$LANG['software'][19]="インストール済み"; 
$LANG['software'][20]="インストール残り"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="アップデート"; 
$LANG['software'][30]="ライセンスタイプ"; 
$LANG['software'][32]="満了"; 
$LANG['software'][44]="ソフトウエアをインストール"; 
$LANG['software'][45]="ソフトウエアをアンインストール"; 
$LANG['software'][46]="チケットを関連付けられる"; 
$LANG['software'][47]="マージ"; 
$LANG['software'][48]="マージ"; 
$LANG['software'][49]="マージ終了後に廃棄されるソフトウェア"; 
$LANG['software'][50]="コンピュータに割り当てられた"; 
$LANG['software'][51]="動作させるには数字は1でなければなりません。"; 

$LANG['softwarecategories'][2]="カテゴリー分類されないソフトウェア"; 
$LANG['softwarecategories'][3]="カテゴリー分類されない公開のソフトウェア"; 
$LANG['softwarecategories'][4]="カテゴリー分類された公開のソフトウェア"; 
$LANG['softwarecategories'][5]="ソフトウェアのカテゴリー分け"; 

$LANG['state'][0]="ステータス"; 
$LANG['state'][6]="アイテム種別"; 
$LANG['state'][7]="アイテムが見付かりませんでした"; 
$LANG['state'][11]="ステータス別集計"; 

$LANG['stats'][0]="表示する統計を選択"; 
$LANG['stats'][1]="グローバル"; 
$LANG['stats'][2]="表示するアイテムなし"; 
$LANG['stats'][3]="アイテム別"; 
$LANG['stats'][5]="開かれているチケット数"; 
$LANG['stats'][6]="平均解決遅延"; 
$LANG['stats'][7]="画像を表示"; 
$LANG['stats'][11]="解決したチケット数"; 
$LANG['stats'][13]="チケット数"; 
$LANG['stats'][15]="平均解決遅延"; 
$LANG['stats'][16]="技術者名"; 
$LANG['stats'][20]="ユーザ名"; 
$LANG['stats'][23]="統計がありません"; 
$LANG['stats'][25]="（実際の）平均解決時間"; 
$LANG['stats'][27]="（実際の）合計解決時間"; 
$LANG['stats'][30]="平均応答遅延"; 
$LANG['stats'][31]="日"; 
$LANG['stats'][33]="分"; 
$LANG['stats'][34]="秒"; 
$LANG['stats'][35]="チケット"; 
$LANG['stats'][44]="業種名"; 
$LANG['stats'][45]="ハードウェア別"; 
$LANG['stats'][47]="インシデントチケット別"; 
$LANG['stats'][48]="（担当者割り当て）"; 
$LANG['stats'][49]="（対応内容）"; 

$LANG['title'][5]="ナレッジベース"; 
$LANG['title'][6]="ネットワーク"; 
$LANG['title'][9]="アイテムステータス"; 
$LANG['title'][10]="ヘルプデスク対応状況（インシデントチケット管理）"; 
$LANG['title'][13]="ユーザ情報"; 
$LANG['title'][14]="外部認証元"; 
$LANG['title'][24]="ユーザサポート"; 
$LANG['title'][26]="メイン"; 
$LANG['title'][27]="機器接続状況"; 
$LANG['title'][28]="チケット"; 
$LANG['title'][30]="PC内部パーツ"; 
$LANG['title'][33]="外部リンク先"; 
$LANG['title'][34]="リンク"; 
$LANG['title'][37]="メモ"; 
$LANG['title'][38]="履歴"; 
$LANG['title'][40]="全てのメモ"; 
$LANG['title'][42]="重度の修正"; 
$LANG['title'][43]="レジストリ"; 

$LANG['tracking'][1]="周辺機器"; 
$LANG['tracking'][2]="全てを検索"; 
$LANG['tracking'][3]="日付が無効なためアップデートはキャンセルされました。"; 
$LANG['tracking'][4]="チケットに緊急の用件は含まれていません。訂正して下さい。"; 
$LANG['tracking'][8]="チケットに記載がありません、再実行して下さい。"; 
$LANG['tracking'][9]="チケットのデフォルト値"; 
$LANG['tracking'][10]="メール受信者のデフォルト値"; 
$LANG['tracking'][24]="文書のチケット"; 
$LANG['tracking'][29]="番号"; 
$LANG['tracking'][30]="新規チケット"; 
$LANG['tracking'][31]="対応中（担当者割り当て済み）"; 
$LANG['tracking'][32]="対応中（計画済み）"; 
$LANG['tracking'][34]="直接"; 
$LANG['tracking'][35]="書き込まれた"; 
$LANG['tracking'][37]="ハードウェアを構成管理台帳から除く時にチケットを残す"; 
$LANG['tracking'][38]="メールが送信されました"; 
$LANG['tracking'][39]="シンプルインターフェースで表示"; 

$LANG['transfer'][1]="転送"; 
$LANG['transfer'][3]="未使用の場合"; 
$LANG['transfer'][4]="移動した要素のリストを空にするため"; 
$LANG['transfer'][5]="転送済みもしくは転送中の要素の追加を継続できます。"; 
$LANG['transfer'][6]="アイテムを移動する前にバックアップを取るよう検討して下さい。"; 
$LANG['transfer'][7]="移動するアイテム"; 
$LANG['transfer'][8]="転送モード"; 

$LANG['update'][88]="データベースのバージョンがインストールされているファイルのバージョンと適合しません。データベースのアップデートが必要です。"; 
$LANG['update'][89]="データベースに対して古いバージョンのファイルでGLPIを実行しようとしています。データベースに対応するバージョンをインストールしてください。"; 
$LANG['update'][90]="データベースアップデートに失敗しました"; 
$LANG['update'][91]="注意！"; 
$LANG['update'][92]="GLPIデータベースをアップデートします："; 
$LANG['update'][93]="データベース接続成功"; 
$LANG['update'][94]="アップデート成功"; 
$LANG['update'][95]="データベース接続に失敗しました。config_db.phpを確認して下さい。"; 
$LANG['update'][96]="全ての管理者がsuper-admin権限になりました"; 
$LANG['update'][105]="アップデート出来ません！"; 
$LANG['update'][106]="GLPIに戻る"; 
$LANG['update'][107]="データベースをアップデートして下さい"; 
$LANG['update'][130]="ロケーションのアップデート"; 
$LANG['update'][131]="階層構造になりました"; 
$LANG['update'][132]="区切り文字を使う場合、新しい階層の生成を自動化するよう設定できます。"; 
$LANG['update'][133]="全ての生成済みロケーションを含んだルートロケーションを指定することができます。"; 
$LANG['update'][134]="区切り文字"; 
$LANG['update'][135]="Rootのロケーション"; 
$LANG['update'][136]="これは新しい階層です。OKなら有効にします。"; 
$LANG['update'][137]="新しい階層構造"; 
$LANG['update'][138]="実際のロケーション"; 
$LANG['update'][139]="テーブルの最適化"; 
$LANG['update'][140]="インデックスを作成中"; 
$LANG['update'][141]="データベーススキーマの変更"; 
$LANG['update'][142]="データの統合"; 

$LANG['users'][1]="タイトル"; 
$LANG['users'][2]="カテゴリー"; 

$LANG['validation'][0]="有効化"; 
$LANG['validation'][1]="有効化依頼を送信"; 
$LANG['validation'][2]="状態"; 
$LANG['validation'][3]="依頼日"; 
$LANG['validation'][4]="有効日"; 
$LANG['validation'][5]="コメント有効化依頼"; 
$LANG['validation'][6]="コメントの有効化"; 
$LANG['validation'][7]="チケットの有効化"; 
$LANG['validation'][9]="有効化待ち"; 
$LANG['validation'][10]="拒否"; 
$LANG['validation'][11]="承認された"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="有効化依頼を送信"; 
$LANG['validation'][15]="有効化待ちのチケット"; 
$LANG['validation'][16]="同意するかどうかは任意"; 
$LANG['validation'][18]="有効化の依頼者"; 
$LANG['validation'][19]="承認済み有効化"; 
$LANG['validation'][20]="拒否された有効化"; 
$LANG['validation'][21]="有効化のユーザー"; 
$LANG['validation'][23]="選択されたユーザーには有効なE-mailアドレスがありません。リクエストは作成されましたが、E-mailは送信されていません。"; 
$LANG['validation'][26]="有効化依頼"; 
$LANG['validation'][27]="有効化のリクエストは送られました。"; 
$LANG['validation'][28]="有効化依頼の状況"; 
$LANG['validation'][29]="同意しない場合、理由を明確にして下さい。"; 
$LANG['validation'][30]="有効化依頼を削除"; 
$LANG['validation'][31]="有効化依頼を更新"; 
$LANG['validation'][32]="有効化要求への回答が実行されました"; 
$LANG['validation'][33]="承認待ちチケットがあります。"; 
?>